"""
Tests
"""

import pytest

from ArWikiCats.legacy_bots.team_work import Get_team_work_Club

fast_data = {
    # "baseball world cup players": "لاعبو كأس العالم لكرة القاعدة",
    # "egyptian second division seasons": "مواسم الدوري المصري الدرجة الثانية",
    # "rugby world cup referees": "حكام كأس العالم للرجبي",
    # "taekwondo competitions": "منافسات تايكوندو",
    "ad alcorcón seasons": "مواسم نادي ألكوركون",
    "aj auxerre matches": "مباريات نادي أوكسير",
    "aj auxerre seasons": "مواسم نادي أوكسير",
    "al ansar fc matches": "مباريات نادي الأنصار",
    "aldershot f.c. managers": "مدربو نادي ألدرشوت",
    "algerian ligue professionnelle 1 seasons": "مواسم الرابطة الجزائرية المحترفة الأولى",
    "american football league seasons": "مواسم دوري كرة القدم الأمريكية",
    "associação chapecoense de futebol seasons": "مواسم نادي شابيكوينسي",
    "atlante f.c. footballers": "لاعبو أتلانتي إف سي",
    "bayer 04 leverkusen non-playing staff": "طاقم باير 04 ليفركوزن غير اللاعبين",
    "bc brno players": "لاعبو نادي برنو لكرة السلة",
    "bc juventus players": "لاعبو أوتينوس يوفنتوس",
    "bc lietkabelis coaches": "مدربو نادي ليتكابليس لكرة السلة",
    "birmingham city f.c. seasons": "مواسم برمنغهام سيتي",
    "blackburn rovers f.c. seasons": "مواسم بلاكبيرن روفرز",
    "blackpool f.c. seasons": "مواسم نادي بلاكبول",
    "borussia dortmund non-playing staff": "طاقم بوروسيا دورتموند غير اللاعبين",
    "boston redskins coaches": "مدربو بوسطن ريدسكينس",
    "buffalo sabres coaches": "مدربو بافالو سيبرز",
    "c.d. tondela matches": "مباريات نادي تونديلا",
    "canton charge players": "لاعبو كانتون شارج",
    "charlotte hornets owners": "ملاك شارلوت هورنتس",
    "copa américa managers": "مدربو كوبا أمريكا",
    "copa américa matches": "مباريات كوبا أمريكا",
    "cs sfaxien players": "لاعبو النادي الرياضي الصفاقسي",
    "dallas cowboys personnel": "أفراد دالاس كاوبويز",
    "deportivo toluca f.c. matches": "مباريات نادي تولوكا",
    "derry city f.c. matches": "مباريات ديري سيتي",
    "fc barcelona managers": "مدربو نادي برشلونة",
    "fc bunyodkor players": "لاعبو نادي بونيودكور لكرة القدم",
    "fc dinamo batumi players": "لاعبو نادي دينامو باتومي",
    "fc gueugnon players": "لاعبو نادي غويونيون",
    "fc haka players": "لاعبو هكا",
    "fc nantes seasons": "مواسم نادي نانت",
    "fc petrolul ploiești seasons": "مواسم نادي بترولول بلويشتي لكرة القدم",
    "fc wacker innsbruck seasons": "مواسم واكر انسبروك",
    "fifa women's world cup managers": "مدربو كأس العالم لكرة القدم للسيدات",
    "fk borac banja luka managers": "مدربو نادي بوراتس بانيا لوكا",
    "fk horizont turnovo seasons": "مواسم نادي هوريزونت تورنوفو",
    "fk spartaks jūrmala players": "لاعبو نادي سبارتاكس يورمالا",
    "gfa league first division players": "لاعبو دوري الدرجة الأولى الغامبي",
    "gimnasia y esgrima de jujuy managers": "مدربو خميناسيا خوخوي",
    "go ahead eagles matches": "مباريات غو أهد إيغلز",
    "harlem globetrotters coaches": "مدربو هارلم غلوبتروترز",
    "houston rockets seasons": "مواسم هيوستن روكتس",
    "if elfsborg managers": "مدربو نادي إلفسبورغ",
    "ifk mariehamn seasons": "مواسم نادي ماريهامن",
    "ipswich town f.c. non-playing staff": "طاقم إيبسويتش تاون غير اللاعبين",
    "kashiwa reysol players": "لاعبو كاشيوا ريسول",
    "kayserispor footballers": "لاعبو كايسري سبور",
    "kazma sc players": "لاعبو نادي كاظمة",
    "knattspyrnufélag reykjavíkur managers": "مدربو ناتدبيرنوفيلاغ ريكيافيكور",
    "liga mx seasons": "مواسم الدوري المكسيكي الممتاز",
    "ljungskile sk players": "لاعبو نادي ليونغسكايل",
    "los angeles angels coaches": "مدربو لوس أنجلوس آنجلز لأنهايم",
    "luxembourgian european commissioners": "مفوضو أوروبيون لوكسمبورغيون",
    "major league baseball owners and executives": "رؤساء تنفيذيون وملاك دوري كرة القاعدة الرئيسي",
    "mc oran players": "لاعبو مولودية وهران",
    "mighty jets f.c. players": "لاعبو مايتي جيتس",
    "music managers": "مدربو موسيقى",
    "nac breda non-playing staff": "طاقم إن أي سي بريدا غير اللاعبين",
    "oakland raiders owners": "ملاك أوكلاند ريدرز",
    "orlando pride players": "لاعبو أورلاندو برايد",
    "pfc beroe stara zagora players": "لاعبو نادي بيروي ستارا زاغورا",
    "philadelphia 76ers lists": "قوائم فيلادلفيا سفنتي سيكسرز",
    "portsmouth f.c. players": "لاعبو نادي بورتسموث",
    "queensland lions fc matches": "مباريات كوينزلاند ليونز",
    "racing club de avellaneda non-playing staff": "طاقم نادي راسينغ غير اللاعبين",
    "rampla juniors managers": "مدربو رامبلا جونيورز",
    "rosario central matches": "مباريات روزاريو سنترال",
    "san antonio spurs owners": "ملاك سان أنطونيو سبرز",
    "silkeborg if players": "لاعبو نادي سيلكيبورج",
    "smouha sc players": "لاعبو نادي سموحة",
    "stade lavallois players": "لاعبو نادي لافال",
    "toronto argonauts lists": "قوائم تورونتو أرغونتس",
    "tunisian ligue professionnelle 2 managers": "مدربو الرابطة التونسية المحترفة الثانية لكرة القدم",
    "u.d. leiria players": "لاعبو يو دي ليريا",
    "uae president's cup matches": "مباريات كأس رئيس دولة الإمارات",
    "udinese calcio players": "لاعبو نادي أودينيزي",
    "utah jazz players": "لاعبو يوتا جاز",
    "vegalta sendai matches": "مباريات فيغالتا سنداي",
    "vegas golden knights coaches": "مدربو فيجاس جولدن نايتس",
    "washington state cougars football players": "لاعبو واشنطن ستايت كوجرز فوتبول",
    "webcomic logos": "شعارات ويب كومكس",
    "western sydney wanderers fc players": "لاعبو نادي وسترن سيدني واندررز",
    "wta tour seasons": "مواسم رابطة محترفات التنس",
}


@pytest.mark.parametrize("category, expected", fast_data.items(), ids=fast_data.keys())
@pytest.mark.fast
def test_fast_data(category: str, expected: str) -> None:
    label = Get_team_work_Club(category)
    assert label == expected



#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label
from ArWikiCats.main_processers.main_resolve import resolve_label_ar

data_1 = {
    "senate of canada": "مجلس شيوخ كندا",
    "senate of iran": "مجلس شيوخ إيران",
    "senate of spain": "مجلس شيوخ إسبانيا",
    "parliament of egypt": "برلمان مصر",
    "parliament of romania": "برلمان رومانيا",
    "senate (france)": "مجلس الشيوخ (فرنسا)",
    "senate (netherlands)": "مجلس الشيوخ (هولندا)",
    "parliament of greenland": "برلمان جرينلاند",
    "parliament of india": "برلمان الهند",
    "parliament of united kingdom": "برلمان المملكة المتحدة",
    "supreme court of israel": "المحكمة العليا الإسرائيلية",
    "supreme court of sri lanka": "المحكمة العليا السريلانكية",
    "supreme court of united states": "المحكمة العليا الأمريكية",
    "supreme court of afghanistan": "المحكمة العليا الأفغانية",
    "supreme court of india": "المحكمة العليا الهندية",
    "supreme court of indonesia": "المحكمة العليا الإندونيسية",
    "supreme court of japan": "المحكمة العليا اليابانية",
    "maryland general assembly": "جمعية ماريلند العامة",
    "politics of emilia-romagna": "سياسة إميليا-رومانيا",
    "malaysian nationality law": "قانون الجنسية الماليزي",
    "united states presidential election 1860": "انتخابات الرئاسة الأمريكية 1860",
    "united states presidential election 1880": "انتخابات الرئاسة الأمريكية 1880",
    "united states presidential election 2008": "انتخابات الرئاسة الأمريكية 2008",
    "united states presidential election 2012": "انتخابات الرئاسة الأمريكية 2012",
    "united states presidential election 2016": "انتخابات الرئاسة الأمريكية 2016",
}

data_2 = {
    "media law": "قانون إعلام",
    "ministry of defence (ukraine)": "وزارة الدفاع (أوكرانيا)",
    "ministry of foreign affairs of people's republic of china": "وزارة الخارجية لجمهورية الصين الشعبية",
    "ministry of higher education and scientific research (jordan)": "وزارة التعليم العالي والبحث العلمي (الأردن)",
    "ministry of intelligence": "وزارة الاستخبارات والأمن الوطني (إيران)",
    "ministry of national defense (colombia)": "وزارة الدفاع (كولومبيا)",
    "mitt romney presidential campaign, 2012": "حملة ميت رومني الرئاسية 2012",
    "national assembly of pakistan": "الجمعية الوطنية في باكستان",
    "natural law": "حق طبيعي",
    "o. j. simpson murder case": "قضية جريمة أو جاي سيمبسون",
    "one-child policy": "سياسة الطفل الواحد",
    "open government": "الحوكمة المفتوحة",
    "permanent court of international justice": "المحكمة الدائمة للعدل الدولي",
    "podemos (spanish political party)": "بوديموس",
    "politics of abruzzo": "سياسة أبروتسو",
    "politics of sicily": "سياسة صقلية",
    "politics of umbria": "سياسة أومبريا",
    "privacy law": "قانون الخصوصية",
    "russian provisional government": "حكومة روسيا المؤقتة",
    "sociology of law": "علم اجتماع القانون",
    "special court for sierra leone": "المحكمة الخاصة بسيراليون",
    "supreme people's assembly": "الجمعية الشعبية العليا",
    "supreme people's court": "المحكمة الشعبية العليا",
    "syrian interim government": "الحكومة السورية المؤقتة",
    "thing (assembly)": "ثينج",
    "treaty of brest-litovsk": "معاهدة برست ليتوفسك",
    "treaty of nanking": "معاهدة نانجينغ",
}

to_test = [
    ("test_yy2_non_1", data_1),
    # ("test_yy2_non_2", data_2),
]


@pytest.mark.parametrize("category, expected", data_1.items(), ids=data_1.keys())
def test_yy2_non_1(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)
    dump_diff(diff_result, name)

    # add_result = {x: v for x, v in data.items() if x in diff_result and "" == diff_result.get(x)}
    # dump_diff(add_result, f"{name}_add")
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#!/usr/bin/python3
"""

"""
from typing import Dict

from ...helps import len_print

formatted_data_of_no_in: Dict[str, str] = {
    "history": "تاريخ",
    "secretaries": "وزراء",
    "banks": "بنوك",
    "treaties": "معاهدات",
}

# NOTE: formatted_data_en_ar_only used in other resolver
formatted_data_en_ar_only: Dict[str, str] = {
    "warm springs of {en}": "ينابيع دائفة في {ar}",
    "hot springs of {en}": "ينابيع حارة في {ar}",
    "acting presidents of {en}": "رؤساء {ar} بالإنابة",
    "bilateral military relations of {en}": "علاقات {ar} الثنائية العسكرية",
    "bilateral relations of {en}": "علاقات {ar} الثنائية",
    "diplomatic missions of {en}": "بعثات {ar} الدبلوماسية",
    "fictional presidents of {en}": "رؤساء {ar} الخياليون",
    "military units and formations of {en}": "وحدات وتشكيلات {ar} العسكرية",
    "military-equipment of {en}": "عتاد {ar} العسكري",
    "national symbols of {en}": "رموز {ar} الوطنية",
    "permanent delegates of {en}": "مندوبو {ar} الدائمون",
    "naval units and formations of {en}": "وحدات وتشكيلات {ar} البحرية",
    "permanent representatives of {en}": "مندوبو {ar} الدائمون",
    "{en} motorcycle grand prix": "جائزة {ar} الكبرى للدراجات النارية",
    "{en} grand prix": "جائزة {ar} الكبرى",
    "university of arts of {en}": "جامعة {ar} للفنون",
    "military installations of {en}": "منشآت {ar} العسكرية",
    # "Germany politics and government templates": "قوالب سياسة وحكومة ألمانيا",
    "{en} politics and government templates": "قوالب سياسة وحكومة {ar}",
    "prehistory of {en}": "{ar} ما قبل التاريخ",
    "history of {en}": "تاريخ {ar}",
    "umayyad governors of {en}": "ولاة {ar} الأمويون",
    "ancient history of {en}": "تاريخ {ar} القديم",
    "contemporary history of {en}": "تاريخ {ar} المعاصر",
    "cultural history of {en}": "تاريخ {ar} الثقافي",
    "demographic history of {en}": "تاريخ {ar} الديموغرافي",
    "early modern history of {en}": "تاريخ {ar} الحديث المبكر",
    "early-modern history of {en}": "تاريخ {ar} الحديث المبكر",
    "economic history of {en}": "تاريخ {ar} الاقتصادي",
    "geographic history of {en}": "تاريخ {ar} الجغرافي",
    "islamic history of {en}": "تاريخ {ar} الإسلامي",
    "legal history of {en}": "تاريخ {ar} القانوني",
    "maritime history of {en}": "تاريخ {ar} البحري",
    "military equipment of {en}": "عتاد {ar} العسكري",
    "military history of {en}": "تاريخ {ar} العسكري",
    "modern history of {en}": "تاريخ {ar} الحديث",
    "natural history of {en}": "تاريخ {ar} الطبيعي",
    "naval history of {en}": "تاريخ {ar} العسكري البحري",
    "nuclear history of {en}": "تاريخ {ar} النووي",
    "political history of {en}": "تاريخ {ar} السياسي",
    "social history of {en}": "تاريخ {ar} الاجتماعي",
    "first league of {en}": "دوري {ar} الممتاز",
    "academic staff of university of {en}": "أعضاء هيئة تدريس جامعة {ar}",
    "ministries of the government of {en}": "وزارات حكومة {ar}",
    "government ministers of {en}": "وزراء {ar}",
    "bilateral treaties of {en}": "معاهدات {ar} الثنائية",
    "secretaries of {en}": "وزراء {ar}",
    "united states secretaries of state": "وزراء خارجية أمريكيون",
    "state cabinet secretaries of {en}": "أعضاء مجلس وزراء {ar}",
    "{en}": "{ar}",
    "{en} women's international footballers": "لاعبات منتخب {ar} لكرة القدم للسيدات",
    "{en} women's youth international footballers": "لاعبات منتخب {ar} لكرة القدم للشابات",
    "{en} international footballers": "لاعبو منتخب {ar} لكرة القدم",
    "police of {en}": "شرطة {ar}",
    "army of {en}": "جيش {ar}",
    "national congress ({en})": "المؤتمر الوطني ({ar})",
    "national council ({en})": "المجلس الوطني ({ar})",
    "national assembly ({en})": "الجمعية الوطنية ({ar})",
    "members of national assembly ({en})": "أعضاء الجمعية الوطنية ({ar})",
    "women members of national assembly ({en})": "عضوات الجمعية الوطنية ({ar})",
    "members of parliament of {en}": "أعضاء برلمان {ar}",
    "women members of parliament of {en}": "عضوات برلمان {ar}",
    "senate ({en})": "مجلس الشيوخ ({ar})",
    "{en} general assembly": "جمعية {ar} العامة",
    "parliament of {en}": "برلمان {ar}",
    "accidental deaths from falls in {en}": "وفيات عرضية نتيجة السقوط في {ar}",
    "bodies of water of {en}": "مسطحات مائية في {ar}",
    "national university of {en}": "جامعة {ar} الوطنية",
    "national library of {en}": "مكتبة {ar} الوطنية",
    "{en} afc asian cup squad": "تشكيلات {ar} في كأس آسيا",
    "{en} afc women's asian cup squad": "تشكيلات {ar} في كأس آسيا للسيدات",
    "{en} board members": "أعضاء مجلس {ar}",
    "{en} conflict": "نزاع {ar}",
    "{en} cup": "كأس {ar}",
    "{en} elections": "انتخابات {ar}",
    "{en} executive cabinet": "مجلس وزراء {ar} التنفيذي",
    "{en} fifa futsal world cup squad": "تشكيلات {ar} في كأس العالم لكرة الصالات",
    "{en} fifa world cup squad": "تشكيلات {ar} في كأس العالم",
    "{en} government personnel": "موظفي حكومة {ar}",
    "{en} government": "حكومة {ar}",
    "{en} governorate": "محافظة {ar}",
    "{en} olympics squad": "تشكيلات {ar} في الألعاب الأولمبية",
    "{en} presidents": "رؤساء {ar}",
    "{en} responses": "استجابات {ar}",
    "{en} summer olympics squad": "تشكيلات {ar} في الألعاب الأولمبية الصيفية",
    "{en} summer olympics": " {ar} في الألعاب الأولمبية الصيفية",
    "{en} territorial judges": "قضاة أقاليم {ar}",
    "{en} territorial officials": "مسؤولو أقاليم {ar}",
    "{en} war and conflict": "حروب ونزاعات {ar}",
    "{en} war": "حرب {ar}",
    "{en} winter olympics squad": "تشكيلات {ar} في الألعاب الأولمبية الشتوية",
    "{en} winter olympics": " {ar} في الألعاب الأولمبية الشتوية",
}


formatted_data_en_ar_only.update(
    {
        # "history of {en}": "تاريخ {ar}",
        f"{x} of {{en}}": f"{v} {{ar}}"
        for x, v in formatted_data_of_no_in.items()
    }
)

# TODO: add data from pop_format
pop_of_without_in_data = {
    "air defence units and formations of {en}": "وحدات وتشكيلات دفاع جوي في {ar}",
    "archipelagoes of {en}": "أرخبيلات {ar}",
    "armies of {en}": "جيوش {ar}",
    "arrondissements of {en}": "دوائر {ar}",
    "bank of {en}": "بنك {ar}",
    "basins of {en}": "أحواض {ar}",
    "battles and operations of {en}": "معارك وعمليات {ar}",
    "battles of {en}": "معارك {ar}",
    "bays of {en}": "خلجان {ar}",
    "beaches of {en}": "شواطئ {ar}",
    "bibliographies of {en}": "ببليوجرافيات {ar}",
    "biota of {en}": "حيويات {ar}",
    "birds of {en}": "طيور {ar}",
    "borders of {en}": "حدود {ar}",
    "cabinet of {en}": "مجلس وزراء {ar}",
    "cabinet secretaries of {en}": "أعضاء مجلس وزراء {ar}",
    "campaigns of {en}": "حملات {ar}",
    "campuses of {en}": "حرم {ar}",
    "cantons of {en}": "كانتونات {ar}",
    "capitals of {en}": "عواصم {ar}",
    "caves of {en}": "كهوف {ar}",
    "chief justices of {en}": "رؤساء قضاء {ar}",
    "children of presidents of {en}": "أبناء رؤساء {ar}",
    "children of prime ministers of {en}": "أبناء رؤساء وزراء {ar}",
    "cities of {en}": "مدن {ar}",
    "city of {en}": "مدينة {ar}",
    "cliffs of {en}": "منحدرات {ar}",
    "climate of {en}": "مناخ {ar}",
    "coastline of {en}": "ساحل {ar}",
    "coasts of {en}": "سواحل {ar}",
    "colleges of {en}": "كليات {ar}",
    "communes of {en}": "بلديات {ar}",
    "consequences of {en}": "عواقب {ar}",
    "court systems of {en}": "أنظمة محاكم {ar}",
    "culture of {en}": "ثقافة {ar}",
    "daughters of {en}": "بنات {ar}",
    "death of {en}": "موت {ar}",
    "depressions of {en}": "منخفضات {ar}",
    "deserts of {en}": "صحاري {ar}",
    "diplomatic-missions-of {en}": "بعثات {ar} الدبلوماسية",
    "dukes of {en}": "دوقات {ar}",
    "economies of {en}": "اقتصادات {ar}",
    "economy of {en}": "اقتصاد {ar}",
    "encyclopedias of {en}": "موسوعات {ar}",
    "environment of {en}": "بيئة {ar}",
    "executions of {en}": "إعدامات {ar}",
    "families of {en}": "عائلات {ar}",
    "fauna of {en}": "حيوانات {ar}",
    "fellows of {en}": "زملاء {ar}",
    "finances of {en}": "مالية {ar}",
    "flags of {en}": "أعلام {ar}",
    "flora of {en}": "نباتات {ar}",
    "foreign relations of {en}": "علاقات {ar} الخارجية",
    "forests and woodlands of {en}": "غابات {ar}",
    "forests of {en}": "غابات {ar}",
    "forms of {en}": "أشكال {ar}",
    "generals of {en}": "جنرالات {ar}",
    "genres of {en}": "أجناس {ar}",
    "geography of {en}": "جغرافيا {ar}",
    "geology of {en}": "جيولوجيا {ar}",
    "government of {en}": "حكومة {ar}",
    "gulfs of {en}": "خلجان {ar}",
    "harbours of {en}": "مرافئ {ar}",
    "heads of state of {en}": "قادة {ar}",
    "heads of {en}": "قادة {ar}",
    "heraldry of {en}": "نبالة {ar}",
    "high commissioners to {en}": "مندوبون ساميون لدى {ar}",
    "hills of {en}": "تلال {ar}",
    "historiography of {en}": "تأريخ {ar}",
    "impact of {en}": "تأثيرات {ar}",
    "impacts of {en}": "آثار {ar}",
    "incidents of {en}": "حوادث {ar}",
    "independence of {en}": "استقلال {ar}",
    "institution of {en}": "مؤسسة {ar}",
    "internment of {en}": "اعتقال {ar}",
    "islands of {en}": "جزر {ar}",
    "judiciary of {en}": "النظام القضائي {ar}",
    "kings of {en}": "ملوك {ar}",
    "lakes of {en}": "بحيرات {ar}",
    "landform of {en}": "تضاريس {ar}",
    "landforms of {en}": "تضاريس {ar}",
    "laws of {en}": "قوانين {ar}",
    "leaders of {en}": "قادة {ar}",
    "lieutenant governors of {en}": "نواب حكام {ar}",
    "lists of {en}": "قوائم {ar}",
    "lords of {en}": "لوردات {ar}",
    "maritime incidents of {en}": "حوادث بحرية {ar}",
    "masters of {en}": "أساتذة {ar}",
    "mayors of {en}": "عمدات {ar}",
    "members of {en}": "أعضاء {ar}",
    "mistresses of {en}": "عشيقات {ar}",
    "mountains of {en}": "جبال {ar}",
    "municipalities of {en}": "بلديات {ar}",
    "music of {en}": "موسيقى {ar}",
    "naval battles of {en}": "معارك بحرية {ar}",
    "occupation of {en}": "احتلال {ar}",
    "order of {en}": "وسام {ar}",
    "parishes of {en}": "أبرشيات {ar}",
    "party chairs of {en}": "رؤساء أحزاب {ar}",
    "peoples of {en}": "شعوب {ar}",
    "persecution of {en}": "اضطهاد {ar}",
    "personalities of {en}": "شخصيات {ar}",
    "plains of {en}": "سهول {ar}",
    "plateaus of {en}": "هضاب {ar}",
    "politics of {en}": "سياسة {ar}",
    "ports and harbours of {en}": "مرافئ وموانئ {ar}",
    "ports of {en}": "موانئ {ar}",
    "presidencies of {en}": "رئاسات {ar}",
    "presidency of {en}": "رئاسة {ar}",
    "president of {en}": "رئيس {ar}",
    "presidents of {en}": "رؤساء {ar}",
    "princesses of {en}": "أميرات {ar}",
    "provinces of {en}": "مقاطعات {ar}",
    "rectors of {en}": "عمدات {ar}",
    "reefs of {en}": "شعاب {ar}",
    "regions of {en}": "مناطق {ar}",
    "rivers of {en}": "أنهار {ar}",
    "rornadoes of {en}": "أعاصير {ar}",
    "royal families of {en}": "عائلات ملكية {ar}",
    "rulers of {en}": "حكام {ar}",
    "seas of {en}": "بحار {ar}",
    "series of {en}": "سلسلات {ar}",
    "sieges of {en}": "حصارات {ar}",
    "society of {en}": "مجتمع {ar}",
    "speakers of {en}": "رؤساء {ar}",
    "spillover of {en}": "امتدادات {ar}",
    "springs of {en}": "ينابيع {ar}",
    "state appellate courts of {en}": "محاكم استئناف ولايات {ar}",
    "state superior courts of {en}": "محاكم عليا {ar}",
    "state treasurers of {en}": "أمناء خزينة ولاية {ar}",
    "straits of {en}": "مضائق {ar}",
    "streams of {en}": "جداول {ar}",
    "subdivisions of {en}": "تقسيمات {ar}",
    "submarines of {en}": "غواصات {ar}",
    "suburbs of {en}": "ضواحي {ar}",
    "sultans of {en}": "سلاطين {ar}",
    "superintendents of public instruction of {en}": "مدراء تعليم عام في {ar}",
    "superior courts of {en}": "محاكم عليا {ar}",
    "symbols of {en}": "رموز {ar}",
    "terminology of {en}": "مصطلحات {ar}",
    "terms of {en}": "فترات {ar}",
    "tour of {en}": "طواف {ar}",
    "treasurers of {en}": "أمناء خزينة {ar}",
    "tribes of {en}": "قبائل {ar}",
    "typhoons of {en}": "تيفونات {ar}",
    "umpires of {en}": "حكام {ar}",
    "underground culture of {en}": "ثقافة باطنية {ar}",
    "university of {en}": "جامعة {ar}",
    "valleys of {en}": "أودية {ar}",
    "variants of {en}": "أشكال {ar}",
    "variations of {en}": "أشكال {ar}",
    "vehicles of {en}": "مركبات {ar}",
    "venues of {en}": "ملاعب {ar}",
    "vice presidents of {en}": "نواب رؤساء {ar}",
    "victims of {en}": "ضحايا {ar}",
    "volcanoes of {en}": "براكين {ar}",
    "wadis of {en}": "وديان {ar}",
    "waterfalls of {en}": "شلالات {ar}",
    "wives of {en}": "زوجات {ar}",
    "works of {en}": "أعمال {ar}",
    "years of {en}": "سنوات {ar}",
}

formatted_data_en_ar_only.update(pop_of_without_in_data)

# TODO: add from_russia_data to formatted_data_en_ar_only
from_russia_data = {
    "agriculture ministers of {en}": "وزراء زراعة في {ar}",
    "aircraft carriers of {en}": "حاملات طائرات في {ar}",
    "airlines of {en}": "شركات طيران في {ar}",
    "ambassadors of {en}": "سفراء {ar}",
    "amphibians of {en}": "برمائيات {ar}",
    "amphibious warfare vessels of {en}": "سفن حربية برمائية في {ar}",
    "archaeology of {en}": "علم الآثار في {ar}",
    "architecture firms of {en}": "شركات هندسة معمارية في {ar}",
    "arthropods of {en}": "مفصليات {ar}",
    "artificial islands of {en}": "جزر اصطناعية في {ar}",
    "artillery of {en}": "مدفعية في {ar}",
    "auxiliary ships of {en}": "سفن مساعدة في {ar}",
    "battlecruisers of {en}": "طرادات معركة في {ar}",
    "battleships of {en}": "بوارج في {ar}",
    "bodies of ice of {en}": "هيئات جليد في {ar}",
    "border crossings of {en}": "معابر حدودية في {ar}",
    "bus manufacturers of {en}": "مصانع الباصات في {ar}",
    "candidates for president of {en}": "مرشحون لمنصب رئيس {ar}",
    "canyons and gorges of {en}": "أخاديد في {ar}",
    "cargo airlines of {en}": "شحن جوي في {ar}",
    "cargo ships of {en}": "سفن بضائع {ar}",
    "cars of {en}": "سيارات في {ar}",
    "charter airlines of {en}": "طيران عارض في {ar}",
    "cinema of {en}": "سينما في {ar}",
    "citizenship of {en}": "المواطنة في {ar}",
    "civil awards and decorations of {en}": "جوائز وأوسمة مدنية في {ar}",
    "constitutions of {en}": "دساتير في {ar}",
    "construction industry of {en}": "صناعة بناء في {ar}",
    "corvettes of {en}": "فرقيطات في {ar}",
    "cruisers of {en}": "طرادات في {ar}",
    "crustaceans of {en}": "قشريات {ar}",
    "cultural depictions of presidents of {en}": "تصوير ثقافي عن رؤساء {ar}",
    "culture ministers of {en}": "وزراء ثقافة في {ar}",
    "currencies of {en}": "عملات في {ar}",
    "defence agencies of {en}": "وكالات دفاع في {ar}",
    "defunct airlines of {en}": "شركات طيران سابقة في {ar}",
    "defunct banks of {en}": "بنوك سابقة في {ar}",
    "defunct motor vehicle manufacturers of {en}": "مصانع سيارات سابقة في {ar}",
    "demographics of {en}": "التركيبة السكانية في {ar}",
    "destroyers of {en}": "مدمرات في {ar}",
    "dinosaurs of {en}": "ديناصورات في {ar}",
    "districts of {en}": "مديريات {ar}",
    "drainage basins of {en}": "أحواض تصريف في {ar}",
    "drug policy of {en}": "سياسة المخدرات في {ar}",
    "dunes of {en}": "كثبان رملية في {ar}",
    "economy ministers of {en}": "وزراء اقتصاد في {ar}",
    "ecoregions of {en}": "مناطق بيئية في {ar}",
    "education ministers of {en}": "وزراء تعليم في {ar}",
    "elizabeth of {en}": "إليزابيث إمبراطورة {ar}",
    "energy ministers of {en}": "وزراء طاقة في {ar}",
    "escort ships of {en}": "سفن مرافقة في {ar}",
    "fast-food chains of {en}": "سلاسل وجبات سريعة في {ar}",
    "featured pictures of {en}": "صور مميزة عن {ar}",
    "federal subjects of {en}": "كيانات {ar} الاتحادية",
    "federal universities of {en}": "جامعات فيدرالية في {ar}",
    "female candidates for president of {en}": "مرشحات لمنصب رئيس {ar}",
    "ferries of {en}": "عبارات في {ar}",
    "finance ministers of {en}": "وزراء مالية في {ar}",
    "first ladies of {en}": "السيدات الأولى في {ar}",
    "fish of {en}": "أسماك {ar}",
    "flags of the federal subjects of {en}": "أعلام كيانات {ar} الاتحادية",
    "folklore of {en}": "فلكور في {ar}",
    "frigates of {en}": "فرقاطات في {ar}",
    "fungi of {en}": "فطريات {ar}",
    "glaciers of {en}": "أنهار جليدية في {ar}",
    "golden ring of {en}": "الجولدن رنج في {ar}",
    "government agencies of {en}": "وكالات حكومية في {ar}",
    "government ministries of federal subjects of {en}": "وزارات حكومة كيانات {ar} الاتحادية",
    "grand duchess anastasia nikolaevna of {en}": "الدوقة الكبرى أناستاسيا نيكولايفنا من {ar}",
    "grasslands of {en}": "أراضي عشبية في {ar}",
    "headlands of {en}": "أراضي رأسية في {ar}",
    "heads of government of {en}": "قادة حكومة {ar}",
    "heads of the federal subjects of {en}": "قادة كيانات {ar} الاتحادية",
    "health ministers of {en}": "وزراء صحة في {ar}",
    "historians of {en}": "مؤرخو {ar}",
    "history of the foreign relations of {en}": "تاريخ علاقات خارجية {ar}",
    "images of {en}": "صور من {ar}",
    "indigenous peoples of {en}": "شعوب أصلية في {ar}",
    "insects of {en}": "حشرات {ar}",
    "internet service providers of {en}": "تزويد خدمة الإنترنت في {ar}",
    "invasions of {en}": "غزوات في {ar}",
    "invertebrates of {en}": "لافقاريات {ar}",
    "justice ministers of {en}": "وزراء عدل في {ar}",
    "languages of {en}": "لغات {ar}",
    "law enforcement agencies of {en}": "وكالات تطبيق القانون في {ar}",
    "law of {en}": "قانون في {ar}",
    "learned societies of {en}": "جمعيات علمية في {ar}",
    "legislatures of the federal subjects of {en}": "هيئات تشريعية في كيانات {ar} الاتحادية",
    "locomotive manufacturers of {en}": "مصانع القاطرات في {ar}",
    "mammals of {en}": "ثدييات {ar}",
    "military academies of {en}": "أكاديميات عسكرية في {ar}",
    "military communications of {en}": "اتصالات عسكرية في {ar}",
    "military logistics of {en}": "لوجستية عسكرية في {ar}",
    "military of {en}": "عسكرية {ar}",
    "military ranks of {en}": "رتب عسكرية في {ar}",
    "military research facilities of {en}": "مرافق بحثية عسكرية في {ar}",
    "military research of {en}": "أبحاث عسكرية في {ar}",
    "mine warfare vessels of {en}": "سفن حرب ألغام في {ar}",
    "minesweepers of {en}": "كاسحات ألغام في {ar}",
    "ministers of defence of {en}": "وزراء دفاع {ar}",
    "ministers of foreign affairs of {en}": "وزراء شؤون خارجية {ar}",
    "ministers of internal affairs of {en}": "وزراء شؤون داخلية {ar}",
    "missile boats of {en}": "قوارب صواريخ في {ar}",
    "motor vehicle manufacturers of {en}": "مصانع السيارات في {ar}",
    "mountain passes of {en}": "ممرات جبلية في {ar}",
    "mountain ranges of {en}": "سلاسل جبلية في {ar}",
    "muslim communities of {en}": "مجتمعات إسلامية في {ar}",
    "national guard of {en}": "الحرس الوطني في {ar}",
    "national parks of {en}": "متنزهات وطنية في {ar}",
    "national trade union centers of {en}": "مراكز نقابية وطنية في {ar}",
    "naturalized citizens of {en}": "متجنسون في {ar}",
    "naval ships of {en}": "سفن قوات بحرية في {ar}",
    "nuclear missiles of {en}": "صواريخ نووية في {ar}",
    "nuclear weapons of {en}": "أسلحة نووية في {ar}",
    "oil fields of {en}": "حقول نفط في {ar}",
    "orders, decorations, and medals of {en}": "مراتب تشريفية وأوسمة وميداليات {ar}",
    "passenger ships of {en}": "سفن ركاب في {ar}",
    "patrol vessels of {en}": "سفن دورية في {ar}",
    "peace treaties of {en}": "معاهدات سلام {ar}",
    "peninsulas of {en}": "أشباه جزر في {ar}",
    "people of {en}": "أشخاص من {ar}",
    "prisoners and detainees of {en}": "سجناء ومعتقلون في {ar}",
    "protected areas of {en}": "مناطق محمية في {ar}",
    "reptiles of {en}": "زواحف {ar}",
    "ridges of {en}": "نتوئات جبلية في {ar}",
    "rock formations of {en}": "تكوينات صخرية في {ar}",
    "rocket engines of {en}": "محركات صواريخ في {ar}",
    "rolling stock of {en}": "القطارات في {ar}",
    "satellites of {en}": "أقمار صناعية تتبع {ar}",
    "service vessels of {en}": "سفن خدمة في {ar}",
    "ships of {en}": "سفن {ar}",
    "shipwrecks of {en}": "حطام سفن في {ar}",
    "shipyards of {en}": "حوض بناء سفن في {ar}",
    "social groups of {en}": "مجموعات اجتماعية في {ar}",
    "spiders of {en}": "عناكب في {ar}",
    "sports organisations of {en}": "منظمات رياضية في {ar}",
    "sports organizations of {en}": "منظمات رياضية في {ar}",
    "stratovolcanoes of {en}": "براكين طبقية في {ar}",
    "supermarkets of {en}": "محلات سوبر ماركت في {ar}",
    "swamps of {en}": "مستنقعات في {ar}",
    "tall ships of {en}": "سفن طويلة في {ar}",
    "tanks of {en}": "دبابات {ar}",
    "torpedoes of {en}": "الطوربيدات في {ar}",
    "training units and formations of {en}": "وحدات وتشكيلات تدريبية في {ar}",
    "truck manufacturers of {en}": "مصانع الشاحنات في {ar}",
    "uninhabited islands of {en}": "جزر غير مأهولة في {ar}",
    "vertebrates of {en}": "فقاريات {ar}",
    "wetlands of {en}": "مناطق رطبة في {ar}",
}

main_data = {
    "{en} amateur international footballers": "لاعبو منتخب {ar} لكرة القدم للهواة",
    "{en} amateur international soccer players": "لاعبو منتخب {ar} لكرة القدم للهواة",
    "{en} amateur international soccer playerss": "لاعبو منتخب {ar} لكرة القدم للهواة",
    "{en} international footballers": "لاعبو منتخب {ar} لكرة القدم",
    "{en} international rally": "رالي {ar} الدولي",
    "{en} international rules football team": "منتخب {ar} لكرة القدم الدولية",
    "{en} international soccer players": "لاعبو منتخب {ar} لكرة القدم",
    "{en} international soccer playerss": "لاعبو منتخب {ar} لكرة القدم",
    "{en} men's a' international footballers": "لاعبو منتخب {ar} لكرة القدم للرجال للمحليين",
    "{en} men's a' international soccer players": "لاعبو منتخب {ar} لكرة القدم للرجال للمحليين",
    "{en} men's a' international soccer playerss": "لاعبو منتخب {ar} لكرة القدم للرجال للمحليين",
    "{en} men's b international footballers": "لاعبو منتخب {ar} لكرة القدم الرديف للرجال",
    "{en} men's b international soccer players": "لاعبو منتخب {ar} لكرة القدم الرديف للرجال",
    "{en} men's b international soccer playerss": "لاعبو منتخب {ar} لكرة القدم الرديف للرجال",
    "{en} men's international footballers": "لاعبو منتخب {ar} لكرة القدم للرجال",
    "{en} men's international soccer players": "لاعبو منتخب {ar} لكرة القدم للرجال",
    "{en} men's international soccer playerss": "لاعبو منتخب {ar} لكرة القدم للرجال",
    "{en} men's youth international footballers": "لاعبو منتخب {ar} لكرة القدم للشباب",
    "{en} men's youth international soccer players": "لاعبو منتخب {ar} لكرة القدم للشباب",
    "{en} men's youth international soccer playerss": "لاعبو منتخب {ar} لكرة القدم للشباب",
    "{en} national football team managers": "مدربو منتخب {ar} لكرة القدم",
    "{en} national team": "منتخبات {ar} الوطنية",
    "{en} national teams": "منتخبات {ar} الوطنية",
    "{en} rally championship": "بطولة {ar} للراليات",
    "{en} sports templates": "قوالب {ar} الرياضية",
    "{en} women's international footballers": "لاعبات منتخب {ar} لكرة القدم للسيدات",
    "{en} women's international soccer players": "لاعبات منتخب {ar} لكرة القدم للسيدات",
    "{en} women's international soccer playerss": "لاعبات منتخب {ar} لكرة القدم للسيدات",
    "{en} women's youth international footballers": "لاعبات منتخب {ar} لكرة القدم للشابات",
    "{en} women's youth international soccer players": "لاعبات منتخب {ar} لكرة القدم للشابات",
    "{en} women's youth international soccer playerss": "لاعبات منتخب {ar} لكرة القدم للشابات",
    "{en} youth international footballers": "لاعبو منتخب {ar} لكرة القدم للشباب",
    "{en} youth international soccer players": "لاعبو منتخب {ar} لكرة القدم للشباب",
    "{en} youth international soccer playerss": "لاعبو منتخب {ar} لكرة القدم للشباب",
}

formatted_data_en_ar_only.update(main_data)

formatted_data_en_ar_only.update(
    {
        x.replace("secretaries of", "secretaries-of"): y
        for x, y in formatted_data_en_ar_only.items()
        if "secretaries of" in x
    }
)

__all__ = [
    "formatted_data_en_ar_only",
]

len_print.data_len(
    "countries_names_data.py",
    {
        "pop_of_without_in_data": pop_of_without_in_data,
        "from_russia_data": from_russia_data,
    },
)



#!/usr/bin/python3
""" """

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.sports_resolvers.nationalities_and_sports import resolve_nats_sport_multi_v2
from ArWikiCats.new_resolvers.sports_resolvers.raw_sports import find_labels_bot, wrap_team_xo_normal_2025_with_ends

test_find_labels_bot_data_0 = {
    "wheelchair rugby league": "دوري الرجبي على الكراسي المتحركة",
    "rugby": "الرجبي",
    "speed skating": "التزلج السريع",
    "martial arts": "الفنون القتالية",
    "baseball": "كرة القاعدة",
    "basketball": "كرة السلة",
    "chess": "الشطرنج",
    "field hockey": "هوكي الميدان",
    "professional wrestling clubs": "أندية مصارعة المحترفين",
    "professional wrestling coaches": "مدربو مصارعة المحترفين",
    "wrestling clubs": "أندية المصارعة",
    "wrestling coaches": "مدربو المصارعة",
}

test_find_labels_bot_data = {
    "wheelchair rugby finals": "نهائيات الرجبي على الكراسي المتحركة",
    "wheelchair rugby league finals": "نهائيات دوري الرجبي على الكراسي المتحركة",
    "rugby finals": "نهائيات الرجبي",
    "rugby league finals": "نهائيات دوري الرجبي",
    "baseball finals": "نهائيات كرة القاعدة",
    "olympic gold medalists in baseball": "فائزون بميداليات ذهبية أولمبية في كرة القاعدة",
    "olympic bronze medalists in baseball": "فائزون بميداليات برونزية أولمبية في كرة القاعدة",
    "baseball champions": "أبطال كرة القاعدة",
    "baseball league": "دوري كرة القاعدة",
    "football league": "دوري كرة القدم",
    "hockey league": "دوري هوكي",
    "ice hockey league": "دوري هوكي الجليد",
    "olympics baseball": "كرة القاعدة في الألعاب الأولمبية",
    "rugby league league": "دوري دوري الرجبي",
    "softball league": "دوري الكرة اللينة",
    "summer olympics baseball": "كرة القاعدة في الألعاب الأولمبية الصيفية",
    "summer olympics basketball chairmen and investors": "رؤساء ومسيرو كرة السلة في الألعاب الأولمبية الصيفية",
    "summer olympics basketball": "كرة السلة في الألعاب الأولمبية الصيفية",
    "summer olympics field hockey": "هوكي الميدان في الألعاب الأولمبية الصيفية",
    "summer olympics football": "كرة القدم في الألعاب الأولمبية الصيفية",
    "summer olympics handball": "كرة اليد في الألعاب الأولمبية الصيفية",
    "summer olympics rugby sevens": "سباعيات الرجبي في الألعاب الأولمبية الصيفية",
    "summer olympics volleyball": "كرة الطائرة في الألعاب الأولمبية الصيفية",
    "summer olympics water polo": "كرة الماء في الألعاب الأولمبية الصيفية",
    "winter olympics baseball": "كرة القاعدة في الألعاب الأولمبية الشتوية",
}


def wrap_callback(category: str) -> str:
    return wrap_team_xo_normal_2025_with_ends(category, callback=find_labels_bot)


@pytest.mark.parametrize("category, expected", test_find_labels_bot_data.items(), ids=test_find_labels_bot_data.keys())
@pytest.mark.fast
def test_Get_New_team_xo_data(category: str, expected: str) -> None:
    label1 = wrap_callback(category)
    assert isinstance(label1, str)
    assert label1 == expected


@pytest.mark.parametrize(
    "category, expected", test_find_labels_bot_data_0.items(), ids=test_find_labels_bot_data_0.keys()
)
@pytest.mark.fast
def test_test_find_labels_bot_data_0(category: str, expected: str) -> None:
    label1 = wrap_callback(category)
    assert isinstance(label1, str)
    assert label1 == expected


TEMPORAL_CASES = [
    ("test_find_labels_bot", test_find_labels_bot_data, wrap_callback),
    ("test_find_labels_bot_2", test_find_labels_bot_data_0, wrap_callback),
]


@pytest.mark.parametrize("name,data,callback", TEMPORAL_CASES)
@pytest.mark.dump
def test_all_dump(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)
    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""Tests for :mod:`make_bots.o_bots.utils`."""

from __future__ import annotations

from typing import Dict

import pytest

from ArWikiCats.legacy_bots.o_bots import utils


@pytest.mark.parametrize(
    "name,suffixes,expected",
    [
        (
            "football governing bodies",
            {"bodies": "هيئات {}", "governing bodies": "هيئات تنظيم {}"},
            ("football", "هيئات تنظيم {}"),
        ),
        ("Alpha beta", {"beta": "template"}, ("Alpha", "template")),
        ("Alpha beta", {" beta": "template"}, ("Alpha", "template")),
        ("Gamma", {"beta": "template"}, None),
    ],
)
def test_match_suffix_template_matches_expected_suffix(
    name: str, suffixes: Dict[str, str], expected: tuple[str, str] | None
) -> None:
    assert utils.match_suffix_template(name, suffixes) == expected


def test_resolve_suffix_template_uses_lookup_and_percent_format() -> None:
    suffixes = {"suffix": "Prefix %s"}
    lookup_calls = []

    def lookup(prefix: str) -> str:
        lookup_calls.append(prefix)
        return "VALUE" if prefix == "Name" else ""

    result = utils.resolve_suffix_template("Name suffix", suffixes, lookup)
    assert result == "Prefix VALUE"
    assert lookup_calls == ["Name"]


def test_resolve_suffix_template_supports_brace_format() -> None:
    suffixes = {"suffix": "Prefix {}"}

    result = utils.resolve_suffix_template("Name suffix", suffixes, lambda prefix: "VALUE")
    assert result == "Prefix VALUE"


def test_first_non_empty_returns_first_value() -> None:
    tables = [{"key": ""}, {"key": "value"}, {"key": "other"}]
    assert utils.first_non_empty("key", tables) == "value"


@pytest.mark.parametrize(
    "label,expected",
    [("", ""), ("كتاب", "الكتاب"), ("بيت جميل", "البيت الجميل")],
)
def test_apply_arabic_article(label: str, expected: str) -> None:
    assert utils.apply_arabic_article(label) == expected



"""

tests related to nationalities_double_v2 resolver

"""

import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_label_ar

data_0 = {
    "Jewish music genres": "أنواع موسيقى يهودية",
    "christian music genres": "أنواع موسيقى مسيحية",
    "christian rock genres": "أنواع روك مسيحي",
    "christian genres": "أنواع مسيحية",
}

male_tests = {
    "American people of South African-Jewish descent": "أمريكيون من أصل جنوب إفريقي يهودي",
    "British people of South African-Jewish descent": "بريطانيون من أصل جنوب إفريقي يهودي",
    "English people of South African-Jewish descent": "إنجليز من أصل جنوب إفريقي يهودي",
    "Israeli people of South African-Jewish descent": "إسرائيليون من أصل جنوب إفريقي يهودي",
    "People of South African-Jewish descent": "أشخاص من أصل جنوب إفريقي يهودي",
    "South African people of Austrian-Jewish descent": "جنوب إفريقيون من أصل نمساوي يهودي",
    "South African people of Belarusian-Jewish descent": "جنوب إفريقيون من أصل بيلاروسي يهودي",
    "South African people of British-Jewish descent": "جنوب إفريقيون من أصل بريطاني يهودي",
    "South African people of Czech-Jewish descent": "جنوب إفريقيون من أصل تشيكي يهودي",
    "South African people of English-Jewish descent": "جنوب إفريقيون من أصل إنجليزي يهودي",
    "South African people of German-Jewish descent": "جنوب إفريقيون من أصل ألماني يهودي",
    "South African people of Hungarian-Jewish descent": "جنوب إفريقيون من أصل مجري يهودي",
    "South African people of Latvian-Jewish descent": "جنوب إفريقيون من أصل لاتفي يهودي",
    "South African people of Lithuanian-Jewish descent": "جنوب إفريقيون من أصل ليتواني يهودي",
    "South African people of Polish-Jewish descent": "جنوب إفريقيون من أصل بولندي يهودي",
    "South African people of Russian-Jewish descent": "جنوب إفريقيون من أصل روسي يهودي",
    "South African-Jewish culture in Israel": "ثقافة جنوب إفريقية يهودية في إسرائيل",
    "South African-Jewish diaspora": "شتات جنوب إفريقي يهودي",
    "Hungarian Nazis executed for war crimes": "مجريون نازيون أعدموا بتهمة جرائم حرب",
    "Antigua and Barbuda people of Russian-Jewish descent": "أنتيغويون وبربوديون من أصل روسي يهودي",
    "Israeli people of North African-Jewish descent": "إسرائيليون من أصل إفريقي شمالي يهودي",
    "North African-Jewish culture in Israel": "ثقافة إفريقية شمالية يهودية في إسرائيل",
    "North African-Jewish culture in the United States": "ثقافة إفريقية شمالية يهودية في الولايات المتحدة",
    "People of North African-Jewish descent": "أشخاص من أصل إفريقي شمالي يهودي",
    "Argentine people of French-Jewish descent": "أرجنتينيون من أصل فرنسي يهودي",
    "French people of Polish-Jewish descent": "فرنسيون من أصل بولندي يهودي",
    "French people of Syrian-Jewish descent": "فرنسيون من أصل سوري يهودي",
    "German people of Lithuanian-Jewish descent": "ألمان من أصل ليتواني يهودي",
    "Indian people of Iraqi-Jewish descent": "هنود من أصل عراقي يهودي",
    "People of Argentine-Jewish descent": "أشخاص من أصل أرجنتيني يهودي",
    "Russian people of Austrian-Jewish descent": "روس من أصل نمساوي يهودي",
    "Colombian people of Spanish-Jewish descent": "كولومبيون من أصل إسباني يهودي",
    "Ethnic groups in Dutch Caribbean": "مجموعات عرقية في كاريبيون هولنديون",
    "Football competitions in Dutch Caribbean": "منافسات كرة قدم في كاريبيون هولنديون",
    "Gender in Dutch Caribbean": "الجنس في كاريبيون هولنديون",
    "Lithuanian-Jewish culture in United States by state": "ثقافة ليتوانية يهودية في الولايات المتحدة حسب الولاية",
    "Men from Dutch Caribbean": "رجال من كاريبيون هولنديون",
    "Men in Dutch Caribbean": "رجال في كاريبيون هولنديون",
    "Peruvian people of Hungarian-Jewish descent": "بيرويون من أصل مجري يهودي",
    "Sports competitions in Dutch Caribbean": "منافسات رياضية في كاريبيون هولنديون",
    "Women from Dutch Caribbean": "نساء من كاريبيون هولنديون",
    "Women in Dutch Caribbean": "المرأة في كاريبيون هولنديون",
    "Romanian people of Hungarian-Jewish descent": "رومان من أصل مجري يهودي",
    "Churches in Dutch Caribbean": "كنائس في كاريبيون هولنديون",
    "Populated places in Dutch Caribbean": "أماكن مأهولة في كاريبيون هولنديون",
}

data_2 = {
    "African-Jewish culture in Israel": "ثقافة إفريقية يهودية في إسرائيل",
    "African-Jewish culture in United States": "ثقافة إفريقية يهودية في الولايات المتحدة",
    "African-Jewish diaspora": "شتات إفريقي يهودي",
    "Algerian people of Moroccan-Jewish descent": "جزائريون من أصل مغربي يهودي",
    "Algerian-Jewish culture in Israel": "ثقافة جزائرية يهودية في إسرائيل",
    "Algerian-Jewish diaspora in France": "شتات جزائري يهودي في فرنسا",
    "Algerian-Jewish diaspora": "شتات جزائري يهودي",
    "American people of Afghan-Jewish descent": "أمريكيون من أصل أفغاني يهودي",
    "American people of African-Jewish descent": "أمريكيون من أصل إفريقي يهودي",
    "American people of Algerian-Jewish descent": "أمريكيون من أصل جزائري يهودي",
    "American people of Argentine-Jewish descent": "أمريكيون من أصل أرجنتيني يهودي",
    "American people of Asian-Jewish descent": "أمريكيون من أصل آسيوي يهودي",
    "American people of Austrian-Jewish descent": "أمريكيون من أصل نمساوي يهودي",
    "American people of Azerbaijani-Jewish descent": "أمريكيون من أصل أذربيجاني يهودي",
    "American people of Belarusian-Jewish descent": "أمريكيون من أصل بيلاروسي يهودي",
    "American people of Belgian-Jewish descent": "أمريكيون من أصل بلجيكي يهودي",
    "American people of Brazilian-Jewish descent": "أمريكيون من أصل برازيلي يهودي",
    "American people of British-Jewish descent": "أمريكيون من أصل بريطاني يهودي",
    "American people of Bulgarian-Jewish descent": "أمريكيون من أصل بلغاري يهودي",
    "American people of Burmese-Jewish descent": "أمريكيون من أصل بورمي يهودي",
    "American people of Cameroonian-Jewish descent": "أمريكيون من أصل كاميروني يهودي",
    "American people of Colombian-Jewish descent": "أمريكيون من أصل كولومبي يهودي",
    "American people of Costa Rican-Jewish descent": "أمريكيون من أصل كوستاريكي يهودي",
    "American people of Croatian-Jewish descent": "أمريكيون من أصل كرواتي يهودي",
    "American people of Cuban-Jewish descent": "أمريكيون من أصل كوبي يهودي",
    "American people of Czech-Jewish descent": "أمريكيون من أصل تشيكي يهودي",
    "American people of Danish-Jewish descent": "أمريكيون من أصل دنماركي يهودي",
    "American people of Dutch-Jewish descent": "أمريكيون من أصل هولندي يهودي",
    "American people of Egyptian-Jewish descent": "أمريكيون من أصل مصري يهودي",
    "American people of English-Jewish descent": "أمريكيون من أصل إنجليزي يهودي",
    "American people of Estonian-Jewish descent": "أمريكيون من أصل إستوني يهودي",
    "American people of Ethiopian-Jewish descent": "أمريكيون من أصل إثيوبي يهودي",
    "American people of European-Jewish descent": "أمريكيون من أصل أوروبي يهودي",
    "American people of Finnish-Jewish descent": "أمريكيون من أصل فنلندي يهودي",
    "American people of French-Jewish descent": "أمريكيون من أصل فرنسي يهودي",
    "American people of Georgian-Jewish descent": "أمريكيون من أصل جورجي يهودي",
    "American people of German-Jewish descent": "أمريكيون من أصل ألماني يهودي",
    "American people of Hungarian-Jewish descent": "أمريكيون من أصل مجري يهودي",
    "American people of Iranian-Jewish descent": "أمريكيون من أصل إيراني يهودي",
    "American people of Iraqi-Jewish descent": "أمريكيون من أصل عراقي يهودي",
    "American people of Irish-Jewish descent": "أمريكيون من أصل أيرلندي يهودي",
    "American people of Italian-Jewish descent": "أمريكيون من أصل إيطالي يهودي",
    "American people of Latvian-Jewish descent": "أمريكيون من أصل لاتفي يهودي",
    "American people of Lebanese-Jewish descent": "أمريكيون من أصل لبناني يهودي",
    "American people of Lithuanian-Jewish descent": "أمريكيون من أصل ليتواني يهودي",
    "American people of Luxembourgian-Jewish descent": "أمريكيون من أصل لوكسمبورغي يهودي",
    "American people of Mexican-Jewish descent": "أمريكيون من أصل مكسيكي يهودي",
    "American people of Moldovan-Jewish descent": "أمريكيون من أصل مولدوفي يهودي",
    "American people of Moroccan-Jewish descent": "أمريكيون من أصل مغربي يهودي",
    "American people of North African-Jewish descent": "أمريكيون من أصل إفريقي شمالي يهودي",
    "American people of Ottoman-Jewish descent": "أمريكيون من أصل عثماني يهودي",
    "American people of Palestinian-Jewish descent": "أمريكيون من أصل فلسطيني يهودي",
    "American people of Polish-Jewish descent": "أمريكيون من أصل بولندي يهودي",
    "American people of Portuguese-Jewish descent": "أمريكيون من أصل برتغالي يهودي",
    "American people of Romanian-Jewish descent": "أمريكيون من أصل روماني يهودي",
    "American people of Russian-Jewish descent": "أمريكيون من أصل روسي يهودي",
    "American people of Scottish-Jewish descent": "أمريكيون من أصل إسكتلندي يهودي",
    "American people of Serbian-Jewish descent": "أمريكيون من أصل صربي يهودي",
    "American people of Slovak-Jewish descent": "أمريكيون من أصل سلوفاكي يهودي",
    "American people of South American-Jewish descent": "أمريكيون من أصل أمريكي جنوبي يهودي",
    "American people of Spanish-Jewish descent": "أمريكيون من أصل إسباني يهودي",
    "American people of Swedish-Jewish descent": "أمريكيون من أصل سويدي يهودي",
    "American people of Swiss-Jewish descent": "أمريكيون من أصل سويسري يهودي",
    "American people of Syrian-Jewish descent": "أمريكيون من أصل سوري يهودي",
    "American people of Tajikistani-Jewish descent": "أمريكيون من أصل طاجيكي يهودي",
    "American people of Tunisian-Jewish descent": "أمريكيون من أصل تونسي يهودي",
    "American people of Turkish-Jewish descent": "أمريكيون من أصل تركي يهودي",
    "American people of Ukrainian-Jewish descent": "أمريكيون من أصل أوكراني يهودي",
    "American people of Uruguayan-Jewish descent": "أمريكيون من أصل أوروغوياني يهودي",
    "American people of Uzbekistani-Jewish descent": "أمريكيون من أصل أوزبكستاني يهودي",
    "American people of Venezuelan-Jewish descent": "أمريكيون من أصل فنزويلي يهودي",
    "American people of Welsh-Jewish descent": "أمريكيون من أصل ويلزي يهودي",
    "American people of Yemeni-Jewish descent": "أمريكيون من أصل يمني يهودي",
    "American-Jewish culture in Israel": "ثقافة أمريكية يهودية في إسرائيل",
    "American-Jewish diaspora": "شتات أمريكي يهودي",
    "Arab-Jewish culture": "ثقافة عربية يهودية",
    "Arab-Jewish surnames": "ألقاب عربية يهودية",
    "Argentine people of Austrian-Jewish descent": "أرجنتينيون من أصل نمساوي يهودي",
    "Argentine people of Belarusian-Jewish descent": "أرجنتينيون من أصل بيلاروسي يهودي",
    "Argentine people of Bulgarian-Jewish descent": "أرجنتينيون من أصل بلغاري يهودي",
    "Argentine people of Czech-Jewish descent": "أرجنتينيون من أصل تشيكي يهودي",
    "Argentine people of Dutch-Jewish descent": "أرجنتينيون من أصل هولندي يهودي",
    "Argentine people of European-Jewish descent": "أرجنتينيون من أصل أوروبي يهودي",
    "Argentine people of French-Jewish descent": "أرجنتينيون من أصل فرنسي يهودي",
    "Argentine people of German-Jewish descent": "أرجنتينيون من أصل ألماني يهودي",
    "Argentine people of Hungarian-Jewish descent": "أرجنتينيون من أصل مجري يهودي",
    "Argentine people of Italian-Jewish descent": "أرجنتينيون من أصل إيطالي يهودي",
    "Argentine people of Latvian-Jewish descent": "أرجنتينيون من أصل لاتفي يهودي",
    "Argentine people of Lithuanian-Jewish descent": "أرجنتينيون من أصل ليتواني يهودي",
    "Argentine people of Moldovan-Jewish descent": "أرجنتينيون من أصل مولدوفي يهودي",
    "Argentine people of Moroccan-Jewish descent": "أرجنتينيون من أصل مغربي يهودي",
    "Argentine people of Polish-Jewish descent": "أرجنتينيون من أصل بولندي يهودي",
    "Argentine people of Portuguese-Jewish descent": "أرجنتينيون من أصل برتغالي يهودي",
    "Argentine people of Romanian-Jewish descent": "أرجنتينيون من أصل روماني يهودي",
    "Argentine people of Russian-Jewish descent": "أرجنتينيون من أصل روسي يهودي",
    "Argentine people of Slovak-Jewish descent": "أرجنتينيون من أصل سلوفاكي يهودي",
    "Argentine people of Syrian-Jewish descent": "أرجنتينيون من أصل سوري يهودي",
    "Argentine people of Turkish-Jewish descent": "أرجنتينيون من أصل تركي يهودي",
    "Argentine people of Ukrainian-Jewish descent": "أرجنتينيون من أصل أوكراني يهودي",
    "Argentine-Jewish culture in Israel": "ثقافة أرجنتينية يهودية في إسرائيل",
    "Argentine-Jewish diaspora": "شتات أرجنتيني يهودي",
    "Asian people of European-Jewish descent": "آسيويون من أصل أوروبي يهودي",
    "Asian-Jewish culture in Israel": "ثقافة آسيوية يهودية في إسرائيل",
    "Asian-Jewish culture in United States": "ثقافة آسيوية يهودية في الولايات المتحدة",
    "Asian-Jewish diaspora": "شتات آسيوي يهودي",
    "Australian people of African-Jewish descent": "أستراليون من أصل إفريقي يهودي",
    "Australian people of Asian-Jewish descent": "أستراليون من أصل آسيوي يهودي",
    "Australian people of Austrian-Jewish descent": "أستراليون من أصل نمساوي يهودي",
    "Australian people of Belarusian-Jewish descent": "أستراليون من أصل بيلاروسي يهودي",
    "Australian people of British-Jewish descent": "أستراليون من أصل بريطاني يهودي",
    "Australian people of Czech-Jewish descent": "أستراليون من أصل تشيكي يهودي",
    "Australian people of Dutch-Jewish descent": "أستراليون من أصل هولندي يهودي",
    "Australian people of Egyptian-Jewish descent": "أستراليون من أصل مصري يهودي",
    "Australian people of English-Jewish descent": "أستراليون من أصل إنجليزي يهودي",
    "Australian people of European-Jewish descent": "أستراليون من أصل أوروبي يهودي",
    "Australian people of French-Jewish descent": "أستراليون من أصل فرنسي يهودي",
    "Australian people of German-Jewish descent": "أستراليون من أصل ألماني يهودي",
    "Australian people of Hungarian-Jewish descent": "أستراليون من أصل مجري يهودي",
    "Australian people of Indian-Jewish descent": "أستراليون من أصل هندي يهودي",
    "Australian people of Iraqi-Jewish descent": "أستراليون من أصل عراقي يهودي",
    "Australian people of Lithuanian-Jewish descent": "أستراليون من أصل ليتواني يهودي",
    "Australian people of Moldovan-Jewish descent": "أستراليون من أصل مولدوفي يهودي",
    "Australian people of Moroccan-Jewish descent": "أستراليون من أصل مغربي يهودي",
    "Australian people of Polish-Jewish descent": "أستراليون من أصل بولندي يهودي",
    "Australian people of Portuguese-Jewish descent": "أستراليون من أصل برتغالي يهودي",
    "Australian people of Romanian-Jewish descent": "أستراليون من أصل روماني يهودي",
    "Australian people of Russian-Jewish descent": "أستراليون من أصل روسي يهودي",
    "Australian people of Scottish-Jewish descent": "أستراليون من أصل إسكتلندي يهودي",
    "Australian people of Slovak-Jewish descent": "أستراليون من أصل سلوفاكي يهودي",
    "Australian people of Ukrainian-Jewish descent": "أستراليون من أصل أوكراني يهودي",
    "Australian-Jewish culture in Israel": "ثقافة أسترالية يهودية في إسرائيل",
    "Australian-Jewish diaspora": "شتات أسترالي يهودي",
    "Austrian people of Bosnia and Herzegovina-Jewish descent": "نمساويون من أصل بوسني يهودي",
    "Austrian people of Croatian-Jewish descent": "نمساويون من أصل كرواتي يهودي",
    "Austrian people of Czech-Jewish descent": "نمساويون من أصل تشيكي يهودي",
    "Austrian people of German-Jewish descent": "نمساويون من أصل ألماني يهودي",
    "Austrian people of Hungarian-Jewish descent": "نمساويون من أصل مجري يهودي",
    "Austrian people of Polish-Jewish descent": "نمساويون من أصل بولندي يهودي",
    "Austrian people of Romanian-Jewish descent": "نمساويون من أصل روماني يهودي",
    "Austrian people of Russian-Jewish descent": "نمساويون من أصل روسي يهودي",
    "Austrian people of Ukrainian-Jewish descent": "نمساويون من أصل أوكراني يهودي",
    "Austrian-Jewish culture in Israel": "ثقافة نمساوية يهودية في إسرائيل",
    "Austrian-Jewish culture in United States": "ثقافة نمساوية يهودية في الولايات المتحدة",
    "Austrian-Jewish diaspora": "شتات نمساوي يهودي",
    "Azerbaijani people of Iranian-Jewish descent": "أذربيجانيون من أصل إيراني يهودي",
    "Bahraini people of Iraqi-Jewish descent": "بحرينيون من أصل عراقي يهودي",
    "Belarusian people of Lithuanian-Jewish descent": "بيلاروسيون من أصل ليتواني يهودي",
    "Belarusian people of Polish-Jewish descent": "بيلاروسيون من أصل بولندي يهودي",
    "Belarusian-Jewish culture in Israel": "ثقافة بيلاروسية يهودية في إسرائيل",
    "Belarusian-Jewish culture in New York (state)": "ثقافة بيلاروسية يهودية في ولاية نيويورك",
    "Belarusian-Jewish culture in New York City": "ثقافة بيلاروسية يهودية في مدينة نيويورك",
    "Belarusian-Jewish culture in United States": "ثقافة بيلاروسية يهودية في الولايات المتحدة",
    "Belarusian-Jewish diaspora": "شتات بيلاروسي يهودي",
    "Belgian people of Egyptian-Jewish descent": "بلجيكيون من أصل مصري يهودي",
    "Belgian people of German-Jewish descent": "بلجيكيون من أصل ألماني يهودي",
    "Belgian people of Italian-Jewish descent": "بلجيكيون من أصل إيطالي يهودي",
    "Belgian people of Moldovan-Jewish descent": "بلجيكيون من أصل مولدوفي يهودي",
    "Belgian people of Polish-Jewish descent": "بلجيكيون من أصل بولندي يهودي",
    "Belgian people of Romanian-Jewish descent": "بلجيكيون من أصل روماني يهودي",
    "Belgian people of Russian-Jewish descent": "بلجيكيون من أصل روسي يهودي",
    "Bolivian people of Austrian-Jewish descent": "بوليفيون من أصل نمساوي يهودي",
    "Bolivian people of German-Jewish descent": "بوليفيون من أصل ألماني يهودي",
    "Bolivian people of Hungarian-Jewish descent": "بوليفيون من أصل مجري يهودي",
    "Bolivian people of Polish-Jewish descent": "بوليفيون من أصل بولندي يهودي",
    "Bosnia and Herzegovina people of Hungarian-Jewish descent": "بوسنيون من أصل مجري يهودي",
    "Brazilian people of African-Jewish descent": "برازيليون من أصل إفريقي يهودي",
    "Brazilian people of Asian-Jewish descent": "برازيليون من أصل آسيوي يهودي",
    "Brazilian people of Austrian-Jewish descent": "برازيليون من أصل نمساوي يهودي",
    "Brazilian people of European-Jewish descent": "برازيليون من أصل أوروبي يهودي",
    "Brazilian people of German-Jewish descent": "برازيليون من أصل ألماني يهودي",
    "Brazilian people of Hungarian-Jewish descent": "برازيليون من أصل مجري يهودي",
    "Brazilian people of Italian-Jewish descent": "برازيليون من أصل إيطالي يهودي",
    "Brazilian people of Lebanese-Jewish descent": "برازيليون من أصل لبناني يهودي",
    "Brazilian people of Lithuanian-Jewish descent": "برازيليون من أصل ليتواني يهودي",
    "Brazilian people of Moroccan-Jewish descent": "برازيليون من أصل مغربي يهودي",
    "Brazilian people of Polish-Jewish descent": "برازيليون من أصل بولندي يهودي",
    "Brazilian people of Portuguese-Jewish descent": "برازيليون من أصل برتغالي يهودي",
    "Brazilian people of Romanian-Jewish descent": "برازيليون من أصل روماني يهودي",
    "Brazilian people of Russian-Jewish descent": "برازيليون من أصل روسي يهودي",
    "Brazilian people of Syrian-Jewish descent": "برازيليون من أصل سوري يهودي",
    "Brazilian people of Turkish-Jewish descent": "برازيليون من أصل تركي يهودي",
    "Brazilian people of Ukrainian-Jewish descent": "برازيليون من أصل أوكراني يهودي",
    "Brazilian people of Uruguayan-Jewish descent": "برازيليون من أصل أوروغوياني يهودي",
    "Brazilian-Jewish diaspora": "شتات برازيلي يهودي",
    "British people of African-Jewish descent": "بريطانيون من أصل إفريقي يهودي",
    "British people of American-Jewish descent": "بريطانيون من أصل أمريكي يهودي",
    "British people of Asian-Jewish descent": "بريطانيون من أصل آسيوي يهودي",
    "British people of Austrian-Jewish descent": "بريطانيون من أصل نمساوي يهودي",
    "British people of Belarusian-Jewish descent": "بريطانيون من أصل بيلاروسي يهودي",
    "British people of Belgian-Jewish descent": "بريطانيون من أصل بلجيكي يهودي",
    "British people of Canadian-Jewish descent": "بريطانيون من أصل كندي يهودي",
    "British people of Croatian-Jewish descent": "بريطانيون من أصل كرواتي يهودي",
    "British people of Czech-Jewish descent": "بريطانيون من أصل تشيكي يهودي",
    "British people of Dutch-Jewish descent": "بريطانيون من أصل هولندي يهودي",
    "British people of Egyptian-Jewish descent": "بريطانيون من أصل مصري يهودي",
    "British people of European-Jewish descent": "بريطانيون من أصل أوروبي يهودي",
    "British people of French-Jewish descent": "بريطانيون من أصل فرنسي يهودي",
    "British people of German-Jewish descent": "بريطانيون من أصل ألماني يهودي",
    "British people of Hungarian-Jewish descent": "بريطانيون من أصل مجري يهودي",
    "British people of Indian-Jewish descent": "بريطانيون من أصل هندي يهودي",
    "British people of Iranian-Jewish descent": "بريطانيون من أصل إيراني يهودي",
    "British people of Iraqi-Jewish descent": "بريطانيون من أصل عراقي يهودي",
    "British people of Italian-Jewish descent": "بريطانيون من أصل إيطالي يهودي",
    "British people of Latvian-Jewish descent": "بريطانيون من أصل لاتفي يهودي",
    "British people of Lebanese-Jewish descent": "بريطانيون من أصل لبناني يهودي",
    "British people of Lithuanian-Jewish descent": "بريطانيون من أصل ليتواني يهودي",
    "British people of Moldovan-Jewish descent": "بريطانيون من أصل مولدوفي يهودي",
    "British people of Moroccan-Jewish descent": "بريطانيون من أصل مغربي يهودي",
    "British people of Palestinian-Jewish descent": "بريطانيون من أصل فلسطيني يهودي",
    "British people of Polish-Jewish descent": "بريطانيون من أصل بولندي يهودي",
    "British people of Portuguese-Jewish descent": "بريطانيون من أصل برتغالي يهودي",
    "British people of Romanian-Jewish descent": "بريطانيون من أصل روماني يهودي",
    "British people of Russian-Jewish descent": "بريطانيون من أصل روسي يهودي",
    "British people of Slovak-Jewish descent": "بريطانيون من أصل سلوفاكي يهودي",
    "British people of Spanish-Jewish descent": "بريطانيون من أصل إسباني يهودي",
    "British people of Swiss-Jewish descent": "بريطانيون من أصل سويسري يهودي",
    "British people of Syrian-Jewish descent": "بريطانيون من أصل سوري يهودي",
    "British people of Turkish-Jewish descent": "بريطانيون من أصل تركي يهودي",
    "British people of Ukrainian-Jewish descent": "بريطانيون من أصل أوكراني يهودي",
    "British-Jewish culture in Israel": "ثقافة بريطانية يهودية في إسرائيل",
    "British-Jewish diaspora": "شتات بريطاني يهودي",
    "Bulgarian-Jewish culture in Israel": "ثقافة بلغارية يهودية في إسرائيل",
    "Bulgarian-Jewish diaspora": "شتات بلغاري يهودي",
    "Burmese people of Iraqi-Jewish descent": "بورميون من أصل عراقي يهودي",
    "Burmese people of Portuguese-Jewish descent": "بورميون من أصل برتغالي يهودي",
    "Canadian people of American-Jewish descent": "كنديون من أصل أمريكي يهودي",
    "Canadian people of Asian-Jewish descent": "كنديون من أصل آسيوي يهودي",
    "Canadian people of Austrian-Jewish descent": "كنديون من أصل نمساوي يهودي",
    "Canadian people of Belarusian-Jewish descent": "كنديون من أصل بيلاروسي يهودي",
    "Canadian people of British-Jewish descent": "كنديون من أصل بريطاني يهودي",
    "Canadian people of Bulgarian-Jewish descent": "كنديون من أصل بلغاري يهودي",
    "Canadian people of Chilean-Jewish descent": "كنديون من أصل تشيلي يهودي",
    "Canadian people of Czech-Jewish descent": "كنديون من أصل تشيكي يهودي",
    "Canadian people of Dutch-Jewish descent": "كنديون من أصل هولندي يهودي",
    "Canadian people of Egyptian-Jewish descent": "كنديون من أصل مصري يهودي",
    "Canadian people of English-Jewish descent": "كنديون من أصل إنجليزي يهودي",
    "Canadian people of European-Jewish descent": "كنديون من أصل أوروبي يهودي",
    "Canadian people of French-Jewish descent": "كنديون من أصل فرنسي يهودي",
    "Canadian people of German-Jewish descent": "كنديون من أصل ألماني يهودي",
    "Canadian people of Hungarian-Jewish descent": "كنديون من أصل مجري يهودي",
    "Canadian people of Iranian-Jewish descent": "كنديون من أصل إيراني يهودي",
    "Canadian people of Iraqi-Jewish descent": "كنديون من أصل عراقي يهودي",
    "Canadian people of Italian-Jewish descent": "كنديون من أصل إيطالي يهودي",
    "Canadian people of Latvian-Jewish descent": "كنديون من أصل لاتفي يهودي",
    "Canadian people of Lebanese-Jewish descent": "كنديون من أصل لبناني يهودي",
    "Canadian people of Lithuanian-Jewish descent": "كنديون من أصل ليتواني يهودي",
    "Canadian people of Moldovan-Jewish descent": "كنديون من أصل مولدوفي يهودي",
    "Canadian people of Moroccan-Jewish descent": "كنديون من أصل مغربي يهودي",
    "Canadian people of Palestinian-Jewish descent": "كنديون من أصل فلسطيني يهودي",
    "Canadian people of Polish-Jewish descent": "كنديون من أصل بولندي يهودي",
    "Canadian people of Romanian-Jewish descent": "كنديون من أصل روماني يهودي",
    "Canadian people of Russian-Jewish descent": "كنديون من أصل روسي يهودي",
    "Canadian people of Scottish-Jewish descent": "كنديون من أصل إسكتلندي يهودي",
    "Canadian people of Slovak-Jewish descent": "كنديون من أصل سلوفاكي يهودي",
    "Canadian people of Syrian-Jewish descent": "كنديون من أصل سوري يهودي",
    "Canadian people of Tunisian-Jewish descent": "كنديون من أصل تونسي يهودي",
    "Canadian people of Ukrainian-Jewish descent": "كنديون من أصل أوكراني يهودي",
    "Canadian people of Uzbekistani-Jewish descent": "كنديون من أصل أوزبكستاني يهودي",
    "Canadian-Jewish culture in Israel": "ثقافة كندية يهودية في إسرائيل",
    "Canadian-Jewish diaspora": "شتات كندي يهودي",
    "Chilean people of Argentine-Jewish descent": "تشيليون من أصل أرجنتيني يهودي",
    "Chilean people of Austrian-Jewish descent": "تشيليون من أصل نمساوي يهودي",
    "Chilean people of Belarusian-Jewish descent": "تشيليون من أصل بيلاروسي يهودي",
    "Chilean people of Bulgarian-Jewish descent": "تشيليون من أصل بلغاري يهودي",
    "Chilean people of Dutch-Jewish descent": "تشيليون من أصل هولندي يهودي",
    "Chilean people of German-Jewish descent": "تشيليون من أصل ألماني يهودي",
    "Chilean people of Hungarian-Jewish descent": "تشيليون من أصل مجري يهودي",
    "Chilean people of Italian-Jewish descent": "تشيليون من أصل إيطالي يهودي",
    "Chilean people of Latvian-Jewish descent": "تشيليون من أصل لاتفي يهودي",
    "Chilean people of Lithuanian-Jewish descent": "تشيليون من أصل ليتواني يهودي",
    "Chilean people of Moldovan-Jewish descent": "تشيليون من أصل مولدوفي يهودي",
    "Chilean people of Polish-Jewish descent": "تشيليون من أصل بولندي يهودي",
    "Chilean people of Romanian-Jewish descent": "تشيليون من أصل روماني يهودي",
    "Chilean people of Russian-Jewish descent": "تشيليون من أصل روسي يهودي",
    "Chilean people of Spanish-Jewish descent": "تشيليون من أصل إسباني يهودي",
    "Chilean people of Ukrainian-Jewish descent": "تشيليون من أصل أوكراني يهودي",
    "Chinese people of American-Jewish descent": "صينيون من أصل أمريكي يهودي",
    "Chinese people of Asian-Jewish descent": "صينيون من أصل آسيوي يهودي",
    "Chinese people of Austrian-Jewish descent": "صينيون من أصل نمساوي يهودي",
    "Chinese people of Dutch-Jewish descent": "صينيون من أصل هولندي يهودي",
    "Chinese people of European-Jewish descent": "صينيون من أصل أوروبي يهودي",
    "Chinese people of German-Jewish descent": "صينيون من أصل ألماني يهودي",
    "Chinese people of Indian-Jewish descent": "صينيون من أصل هندي يهودي",
    "Chinese people of Iraqi-Jewish descent": "صينيون من أصل عراقي يهودي",
    "Chinese people of Polish-Jewish descent": "صينيون من أصل بولندي يهودي",
    "Chinese people of Russian-Jewish descent": "صينيون من أصل روسي يهودي",
    "Chinese people of Ukrainian-Jewish descent": "صينيون من أصل أوكراني يهودي",
    "Chinese-Jewish diaspora": "شتات صيني يهودي",
    "Colombian people of British-Jewish descent": "كولومبيون من أصل بريطاني يهودي",
    "Colombian people of Dutch-Jewish descent": "كولومبيون من أصل هولندي يهودي",
    "Colombian people of English-Jewish descent": "كولومبيون من أصل إنجليزي يهودي",
    "Colombian people of German-Jewish descent": "كولومبيون من أصل ألماني يهودي",
    "Colombian people of Lithuanian-Jewish descent": "كولومبيون من أصل ليتواني يهودي",
    "Colombian people of Polish-Jewish descent": "كولومبيون من أصل بولندي يهودي",
    "Colombian people of Romanian-Jewish descent": "كولومبيون من أصل روماني يهودي",
    "Colombian people of Syrian-Jewish descent": "كولومبيون من أصل سوري يهودي",
    "Colombian people of Ukrainian-Jewish descent": "كولومبيون من أصل أوكراني يهودي",
    "Costa Rican people of Polish-Jewish descent": "كوستاريكيون من أصل بولندي يهودي",
    "Croatian people of Austrian-Jewish descent": "كروات من أصل نمساوي يهودي",
    "Croatian people of Bosnia and Herzegovina-Jewish descent": "كروات من أصل بوسني يهودي",
    "Croatian people of Czech-Jewish descent": "كروات من أصل تشيكي يهودي",
    "Croatian people of German-Jewish descent": "كروات من أصل ألماني يهودي",
    "Croatian people of Hungarian-Jewish descent": "كروات من أصل مجري يهودي",
    "Croatian people of Italian-Jewish descent": "كروات من أصل إيطالي يهودي",
    "Croatian people of Polish-Jewish descent": "كروات من أصل بولندي يهودي",
    "Croatian people of Romanian-Jewish descent": "كروات من أصل روماني يهودي",
    "Croatian people of Russian-Jewish descent": "كروات من أصل روسي يهودي",
    "Croatian people of Serbian-Jewish descent": "كروات من أصل صربي يهودي",
    "Croatian people of Slovak-Jewish descent": "كروات من أصل سلوفاكي يهودي",
    "Croatian people of Spanish-Jewish descent": "كروات من أصل إسباني يهودي",
    "Croatian people of Ukrainian-Jewish descent": "كروات من أصل أوكراني يهودي",
    "Cuban people of German-Jewish descent": "كوبيون من أصل ألماني يهودي",
    "Cuban people of Polish-Jewish descent": "كوبيون من أصل بولندي يهودي",
    "Cuban people of Romanian-Jewish descent": "كوبيون من أصل روماني يهودي",
    "Cuban people of Spanish-Jewish descent": "كوبيون من أصل إسباني يهودي",
    "Czech people of German-Jewish descent": "تشيكيون من أصل ألماني يهودي",
    "Czech people of Polish-Jewish descent": "تشيكيون من أصل بولندي يهودي",
    "Czech people of Russian-Jewish descent": "تشيكيون من أصل روسي يهودي",
    "Czech people of Ukrainian-Jewish descent": "تشيكيون من أصل أوكراني يهودي",
    "Czech-Jewish culture in Israel": "ثقافة تشيكية يهودية في إسرائيل",
    "Czech-Jewish culture in United States": "ثقافة تشيكية يهودية في الولايات المتحدة",
    "Czech-Jewish diaspora": "شتات تشيكي يهودي",
    "Danish people of German-Jewish descent": "دنماركيون من أصل ألماني يهودي",
    "Danish people of Latvian-Jewish descent": "دنماركيون من أصل لاتفي يهودي",
    "Danish people of Polish-Jewish descent": "دنماركيون من أصل بولندي يهودي",
    "Danish people of Portuguese-Jewish descent": "دنماركيون من أصل برتغالي يهودي",
    "Danish people of Russian-Jewish descent": "دنماركيون من أصل روسي يهودي",
    "Danish people of Yemeni-Jewish descent": "دنماركيون من أصل يمني يهودي",
    "Democratic Republic of Congo people of Polish-Jewish descent": "كونغويون ديمقراطيون من أصل بولندي يهودي",
    "Dominican Republic people of Dutch-Jewish descent": "دومينيكانيون من أصل هولندي يهودي",
    "Dominican Republic people of German-Jewish descent": "دومينيكانيون من أصل ألماني يهودي",
    "Dutch people of Asian-Jewish descent": "هولنديون من أصل آسيوي يهودي",
    "Dutch people of European-Jewish descent": "هولنديون من أصل أوروبي يهودي",
    "Dutch people of French-Jewish descent": "هولنديون من أصل فرنسي يهودي",
    "Dutch people of German-Jewish descent": "هولنديون من أصل ألماني يهودي",
    "Dutch people of Polish-Jewish descent": "هولنديون من أصل بولندي يهودي",
    "Dutch people of Portuguese-Jewish descent": "هولنديون من أصل برتغالي يهودي",
    "Dutch people of Russian-Jewish descent": "هولنديون من أصل روسي يهودي",
    "Dutch people of Spanish-Jewish descent": "هولنديون من أصل إسباني يهودي",
    "Dutch people of Ukrainian-Jewish descent": "هولنديون من أصل أوكراني يهودي",
    "Dutch-Jewish culture in Israel": "ثقافة هولندية يهودية في إسرائيل",
    "Dutch-Jewish culture in United Kingdom": "ثقافة هولندية يهودية في المملكة المتحدة",
    "Dutch-Jewish culture in United States": "ثقافة هولندية يهودية في الولايات المتحدة",
    "Dutch-Jewish diaspora": "شتات هولندي يهودي",
    "Ecuadorian people of German-Jewish descent": "إكوادوريون من أصل ألماني يهودي",
    "Ecuadorian people of Romanian-Jewish descent": "إكوادوريون من أصل روماني يهودي",
    "Egyptian people of Italian-Jewish descent": "مصريون من أصل إيطالي يهودي",
    "Egyptian people of Polish-Jewish descent": "مصريون من أصل بولندي يهودي",
    "Egyptian people of Turkish-Jewish descent": "مصريون من أصل تركي يهودي",
    "Egyptian-Jewish culture in Israel": "ثقافة مصرية يهودية في إسرائيل",
    "Egyptian-Jewish diaspora in United States": "شتات مصري يهودي في الولايات المتحدة",
    "Egyptian-Jewish diaspora": "شتات مصري يهودي",
    "English people of Algerian-Jewish descent": "إنجليز من أصل جزائري يهودي",
    "English people of American-Jewish descent": "إنجليز من أصل أمريكي يهودي",
    "English people of Austrian-Jewish descent": "إنجليز من أصل نمساوي يهودي",
    "English people of Belarusian-Jewish descent": "إنجليز من أصل بيلاروسي يهودي",
    "English people of Canadian-Jewish descent": "إنجليز من أصل كندي يهودي",
    "English people of Czech-Jewish descent": "إنجليز من أصل تشيكي يهودي",
    "English people of Dutch-Jewish descent": "إنجليز من أصل هولندي يهودي",
    "English people of Egyptian-Jewish descent": "إنجليز من أصل مصري يهودي",
    "English people of German-Jewish descent": "إنجليز من أصل ألماني يهودي",
    "English people of Hungarian-Jewish descent": "إنجليز من أصل مجري يهودي",
    "English people of Indian-Jewish descent": "إنجليز من أصل هندي يهودي",
    "English people of Iranian-Jewish descent": "إنجليز من أصل إيراني يهودي",
    "English people of Iraqi-Jewish descent": "إنجليز من أصل عراقي يهودي",
    "English people of Irish-Jewish descent": "إنجليز من أصل أيرلندي يهودي",
    "English people of Italian-Jewish descent": "إنجليز من أصل إيطالي يهودي",
    "English people of Latvian-Jewish descent": "إنجليز من أصل لاتفي يهودي",
    "English people of Lebanese-Jewish descent": "إنجليز من أصل لبناني يهودي",
    "English people of Lithuanian-Jewish descent": "إنجليز من أصل ليتواني يهودي",
    "English people of Polish-Jewish descent": "إنجليز من أصل بولندي يهودي",
    "English people of Portuguese-Jewish descent": "إنجليز من أصل برتغالي يهودي",
    "English people of Romanian-Jewish descent": "إنجليز من أصل روماني يهودي",
    "English people of Russian-Jewish descent": "إنجليز من أصل روسي يهودي",
    "English people of Spanish-Jewish descent": "إنجليز من أصل إسباني يهودي",
    "English people of Tunisian-Jewish descent": "إنجليز من أصل تونسي يهودي",
    "English people of Turkish-Jewish descent": "إنجليز من أصل تركي يهودي",
    "English people of Ukrainian-Jewish descent": "إنجليز من أصل أوكراني يهودي",
    "English-Jewish culture in Israel": "ثقافة إنجليزية يهودية في إسرائيل",
    "English-Jewish culture in United States": "ثقافة إنجليزية يهودية في الولايات المتحدة",
    "English-Jewish diaspora": "شتات إنجليزي يهودي",
    "Ethiopian-Jewish culture in Israel": "ثقافة إثيوبية يهودية في إسرائيل",
    "Ethiopian-Jewish culture in United States": "ثقافة إثيوبية يهودية في الولايات المتحدة",
    "Ethiopian-Jewish diaspora": "شتات إثيوبي يهودي",
    "European people of Asian-Jewish descent": "أوروبيون من أصل آسيوي يهودي",
    "European people of European-Jewish descent": "أوروبيون من أصل أوروبي يهودي",
    "European-Jewish culture in Canada": "ثقافة أوروبية يهودية في كندا",
    "European-Jewish culture in Israel": "ثقافة أوروبية يهودية في إسرائيل",
    "European-Jewish culture in Jerusalem": "ثقافة أوروبية يهودية في القدس",
    "European-Jewish culture in Mexico": "ثقافة أوروبية يهودية في المكسيك",
    "European-Jewish culture in North America": "ثقافة أوروبية يهودية في أمريكا الشمالية",
    "European-Jewish culture in United Kingdom": "ثقافة أوروبية يهودية في المملكة المتحدة",
    "European-Jewish culture in United States": "ثقافة أوروبية يهودية في الولايات المتحدة",
    "European-Jewish diaspora": "شتات أوروبي يهودي",
    "Filipino people of American-Jewish descent": "فلبينيون من أصل أمريكي يهودي",
    "Filipino people of German-Jewish descent": "فلبينيون من أصل ألماني يهودي",
    "Filipino people of Polish-Jewish descent": "فلبينيون من أصل بولندي يهودي",
    "Filipino people of Portuguese-Jewish descent": "فلبينيون من أصل برتغالي يهودي",
    "Filipino people of Ukrainian-Jewish descent": "فلبينيون من أصل أوكراني يهودي",
    "Finnish people of Polish-Jewish descent": "فنلنديون من أصل بولندي يهودي",
    "Finnish people of Russian-Jewish descent": "فنلنديون من أصل روسي يهودي",
    "French people of African-Jewish descent": "فرنسيون من أصل إفريقي يهودي",
    "French people of Algerian-Jewish descent": "فرنسيون من أصل جزائري يهودي",
    "French people of Asian-Jewish descent": "فرنسيون من أصل آسيوي يهودي",
    "French people of Austrian-Jewish descent": "فرنسيون من أصل نمساوي يهودي",
    "French people of Belarusian-Jewish descent": "فرنسيون من أصل بيلاروسي يهودي",
    "French people of British-Jewish descent": "فرنسيون من أصل بريطاني يهودي",
    "French people of Czech-Jewish descent": "فرنسيون من أصل تشيكي يهودي",
    "French people of Dutch-Jewish descent": "فرنسيون من أصل هولندي يهودي",
    "French people of Egyptian-Jewish descent": "فرنسيون من أصل مصري يهودي",
    "French people of English-Jewish descent": "فرنسيون من أصل إنجليزي يهودي",
    "French people of Ethiopian-Jewish descent": "فرنسيون من أصل إثيوبي يهودي",
    "French people of European-Jewish descent": "فرنسيون من أصل أوروبي يهودي",
    "French people of German-Jewish descent": "فرنسيون من أصل ألماني يهودي",
    "French people of Hungarian-Jewish descent": "فرنسيون من أصل مجري يهودي",
    "French people of Iraqi-Jewish descent": "فرنسيون من أصل عراقي يهودي",
    "French people of Italian-Jewish descent": "فرنسيون من أصل إيطالي يهودي",
    "French people of Latvian-Jewish descent": "فرنسيون من أصل لاتفي يهودي",
    "French people of Lebanese-Jewish descent": "فرنسيون من أصل لبناني يهودي",
    "French people of Lithuanian-Jewish descent": "فرنسيون من أصل ليتواني يهودي",
    "French people of Moldovan-Jewish descent": "فرنسيون من أصل مولدوفي يهودي",
    "French people of Moroccan-Jewish descent": "فرنسيون من أصل مغربي يهودي",
    "French people of Polish-Jewish descent": "فرنسيون من أصل بولندي يهودي",
    "French people of Portuguese-Jewish descent": "فرنسيون من أصل برتغالي يهودي",
    "French people of Romanian-Jewish descent": "فرنسيون من أصل روماني يهودي",
    "French people of Russian-Jewish descent": "فرنسيون من أصل روسي يهودي",
    "French people of Spanish-Jewish descent": "فرنسيون من أصل إسباني يهودي",
    "French people of Swiss-Jewish descent": "فرنسيون من أصل سويسري يهودي",
    "French people of Syrian-Jewish descent": "فرنسيون من أصل سوري يهودي",
    "French people of Tunisian-Jewish descent": "فرنسيون من أصل تونسي يهودي",
    "French people of Turkish-Jewish descent": "فرنسيون من أصل تركي يهودي",
    "French people of Ukrainian-Jewish descent": "فرنسيون من أصل أوكراني يهودي",
    "French people of Yemeni-Jewish descent": "فرنسيون من أصل يمني يهودي",
    "French-Jewish culture in Israel": "ثقافة فرنسية يهودية في إسرائيل",
    "French-Jewish culture in United States": "ثقافة فرنسية يهودية في الولايات المتحدة",
    "French-Jewish diaspora": "شتات فرنسي يهودي",
    "Georgian-Jewish culture in Israel": "ثقافة جورجية يهودية في إسرائيل",
    "Georgian-Jewish culture in United States": "ثقافة جورجية يهودية في الولايات المتحدة",
    "Georgian-Jewish culture": "ثقافة جورجية يهودية",
    "German people of Asian-Jewish descent": "ألمان من أصل آسيوي يهودي",
    "German people of Austrian-Jewish descent": "ألمان من أصل نمساوي يهودي",
    "German people of Belarusian-Jewish descent": "ألمان من أصل بيلاروسي يهودي",
    "German people of Croatian-Jewish descent": "ألمان من أصل كرواتي يهودي",
    "German people of Czech-Jewish descent": "ألمان من أصل تشيكي يهودي",
    "German people of Danish-Jewish descent": "ألمان من أصل دنماركي يهودي",
    "German people of Dutch-Jewish descent": "ألمان من أصل هولندي يهودي",
    "German people of European-Jewish descent": "ألمان من أصل أوروبي يهودي",
    "German people of Hungarian-Jewish descent": "ألمان من أصل مجري يهودي",
    "German people of Lithuanian-Jewish descent": "ألمان من أصل ليتواني يهودي",
    "German people of Polish-Jewish descent": "ألمان من أصل بولندي يهودي",
    "German people of Russian-Jewish descent": "ألمان من أصل روسي يهودي",
    "German people of Slovak-Jewish descent": "ألمان من أصل سلوفاكي يهودي",
    "German people of Ukrainian-Jewish descent": "ألمان من أصل أوكراني يهودي",
    "German-Jewish culture in Baltimore": "ثقافة ألمانية يهودية في بالتيمور",
    "German-Jewish culture in Israel": "ثقافة ألمانية يهودية في إسرائيل",
    "German-Jewish culture in Jerusalem": "ثقافة ألمانية يهودية في القدس",
    "German-Jewish culture in Maryland": "ثقافة ألمانية يهودية في ماريلند",
    "German-Jewish culture in New York (state)": "ثقافة ألمانية يهودية في ولاية نيويورك",
    "German-Jewish culture in New York City": "ثقافة ألمانية يهودية في مدينة نيويورك",
    "German-Jewish culture in Pennsylvania": "ثقافة ألمانية يهودية في بنسلفانيا",
    "German-Jewish culture in United Kingdom": "ثقافة ألمانية يهودية في المملكة المتحدة",
    "German-Jewish culture in United States by city": "ثقافة ألمانية يهودية في الولايات المتحدة حسب المدينة",
    "German-Jewish culture in United States by state": "ثقافة ألمانية يهودية في الولايات المتحدة حسب الولاية",
    "German-Jewish culture in United States": "ثقافة ألمانية يهودية في الولايات المتحدة",
    "German-Jewish diaspora": "شتات ألماني يهودي",
    "Gibraltarian people of Moroccan-Jewish descent": "جبل طارقيون من أصل مغربي يهودي",
    "Gibraltarian people of Spanish-Jewish descent": "جبل طارقيون من أصل إسباني يهودي",
    "Greek people of Ukrainian-Jewish descent": "يونانيون من أصل أوكراني يهودي",
    "Guyanese people of Hungarian-Jewish descent": "غيانيون من أصل مجري يهودي",
    "Haitian people of Syrian-Jewish descent": "هايتيون من أصل سوري يهودي",
    "Honduran people of Romanian-Jewish descent": "هندوراسيون من أصل روماني يهودي",
    "Honduran people of Spanish-Jewish descent": "هندوراسيون من أصل إسباني يهودي",
    "Hong Kong people of Dutch-Jewish descent": "هونغ كونغيون من أصل هولندي يهودي",
    "Hong Kong people of Indian-Jewish descent": "هونغ كونغيون من أصل هندي يهودي",
    "Hong Kong people of Iraqi-Jewish descent": "هونغ كونغيون من أصل عراقي يهودي",
    "Hungarian people of Czech-Jewish descent": "مجريون من أصل تشيكي يهودي",
    "Hungarian people of Georgian-Jewish descent": "مجريون من أصل جورجي يهودي",
    "Hungarian people of Polish-Jewish descent": "مجريون من أصل بولندي يهودي",
    "Hungarian-Jewish culture in Israel": "ثقافة مجرية يهودية في إسرائيل",
    "Hungarian-Jewish culture in New York (state)": "ثقافة مجرية يهودية في ولاية نيويورك",
    "Hungarian-Jewish culture in New York City": "ثقافة مجرية يهودية في مدينة نيويورك",
    "Hungarian-Jewish culture in United States": "ثقافة مجرية يهودية في الولايات المتحدة",
    "Hungarian-Jewish diaspora": "شتات مجري يهودي",
    "Icelandic people of German-Jewish descent": "آيسلنديون من أصل ألماني يهودي",
    "Indian people of Austrian-Jewish descent": "هنود من أصل نمساوي يهودي",
    "Indian people of German-Jewish descent": "هنود من أصل ألماني يهودي",
    "Indian people of Hungarian-Jewish descent": "هنود من أصل مجري يهودي",
    "Indian people of Iraqi-Jewish descent": "هنود من أصل عراقي يهودي",
    "Indian people of Portuguese-Jewish descent": "هنود من أصل برتغالي يهودي",
    "Indian people of Russian-Jewish descent": "هنود من أصل روسي يهودي",
    "Indian-Jewish culture in Israel": "ثقافة هندية يهودية في إسرائيل",
    "Indian-Jewish diaspora": "شتات هندي يهودي",
    "Indonesian people of Austrian-Jewish descent": "إندونيسيون من أصل نمساوي يهودي",
    "Indonesian people of Dutch-Jewish descent": "إندونيسيون من أصل هولندي يهودي",
    "Indonesian people of French-Jewish descent": "إندونيسيون من أصل فرنسي يهودي",
    "Indonesian people of German-Jewish descent": "إندونيسيون من أصل ألماني يهودي",
    "Indonesian people of Polish-Jewish descent": "إندونيسيون من أصل بولندي يهودي",
    "Iranian people of Russian-Jewish descent": "إيرانيون من أصل روسي يهودي",
    "Iranian-Jewish culture in Israel": "ثقافة إيرانية يهودية في إسرائيل",
    "Iranian-Jewish culture in United States": "ثقافة إيرانية يهودية في الولايات المتحدة",
    "Iranian-Jewish diaspora": "شتات إيراني يهودي",
    "Iraqi-Jewish culture in Israel": "ثقافة عراقية يهودية في إسرائيل",
    "Iraqi-Jewish diaspora in Asia": "شتات عراقي يهودي في آسيا",
    "Iraqi-Jewish diaspora": "شتات عراقي يهودي",
    "Irish people of British-Jewish descent": "أيرلنديون من أصل بريطاني يهودي",
    "Irish people of English-Jewish descent": "أيرلنديون من أصل إنجليزي يهودي",
    "Irish people of German-Jewish descent": "أيرلنديون من أصل ألماني يهودي",
    "Irish people of Lithuanian-Jewish descent": "أيرلنديون من أصل ليتواني يهودي",
    "Irish people of Polish-Jewish descent": "أيرلنديون من أصل بولندي يهودي",
    "Irish people of Russian-Jewish descent": "أيرلنديون من أصل روسي يهودي",
    "Irish people of Ukrainian-Jewish descent": "أيرلنديون من أصل أوكراني يهودي",
    "Israeli people of Afghan-Jewish descent": "إسرائيليون من أصل أفغاني يهودي",
    "Israeli people of African-Jewish descent": "إسرائيليون من أصل إفريقي يهودي",
    "Israeli people of Algerian-Jewish descent": "إسرائيليون من أصل جزائري يهودي",
    "Israeli people of American-Jewish descent": "إسرائيليون من أصل أمريكي يهودي",
    "Israeli people of Argentine-Jewish descent": "إسرائيليون من أصل أرجنتيني يهودي",
    "Israeli people of Armenian-Jewish descent": "إسرائيليون من أصل أرميني يهودي",
    "Israeli people of Asian-Jewish descent": "إسرائيليون من أصل آسيوي يهودي",
    "Israeli people of Australian-Jewish descent": "إسرائيليون من أصل أسترالي يهودي",
    "Israeli people of Austrian-Jewish descent": "إسرائيليون من أصل نمساوي يهودي",
    "Israeli people of Azerbaijani-Jewish descent": "إسرائيليون من أصل أذربيجاني يهودي",
    "Israeli people of Belarusian-Jewish descent": "إسرائيليون من أصل بيلاروسي يهودي",
    "Israeli people of Belgian-Jewish descent": "إسرائيليون من أصل بلجيكي يهودي",
    "Israeli people of Bosnia and Herzegovina-Jewish descent": "إسرائيليون من أصل بوسني يهودي",
    "Israeli people of Brazilian-Jewish descent": "إسرائيليون من أصل برازيلي يهودي",
    "Israeli people of British-Jewish descent": "إسرائيليون من أصل بريطاني يهودي",
    "Israeli people of Bulgarian-Jewish descent": "إسرائيليون من أصل بلغاري يهودي",
    "Israeli people of Canadian-Jewish descent": "إسرائيليون من أصل كندي يهودي",
    "Israeli people of Chinese-Jewish descent": "إسرائيليون من أصل صيني يهودي",
    "Israeli people of Colombian-Jewish descent": "إسرائيليون من أصل كولومبي يهودي",
    "Israeli people of Croatian-Jewish descent": "إسرائيليون من أصل كرواتي يهودي",
    "Israeli people of Czech-Jewish descent": "إسرائيليون من أصل تشيكي يهودي",
    "Israeli people of Czechoslovak-Jewish descent": "إسرائيليون من أصل تشيكوسلوفاكي يهودي",
    "Israeli people of Danish-Jewish descent": "إسرائيليون من أصل دنماركي يهودي",
    "Israeli people of Dutch-Jewish descent": "إسرائيليون من أصل هولندي يهودي",
    "Israeli people of Egyptian-Jewish descent": "إسرائيليون من أصل مصري يهودي",
    "Israeli people of English-Jewish descent": "إسرائيليون من أصل إنجليزي يهودي",
    "Israeli people of Estonian-Jewish descent": "إسرائيليون من أصل إستوني يهودي",
    "Israeli people of Ethiopian-Jewish descent": "إسرائيليون من أصل إثيوبي يهودي",
    "Israeli people of European-Jewish descent": "إسرائيليون من أصل أوروبي يهودي",
    "Israeli people of Finnish-Jewish descent": "إسرائيليون من أصل فنلندي يهودي",
    "Israeli people of French-Jewish descent": "إسرائيليون من أصل فرنسي يهودي",
    "Israeli people of Georgian-Jewish descent": "إسرائيليون من أصل جورجي يهودي",
    "Israeli people of German-Jewish descent": "إسرائيليون من أصل ألماني يهودي",
    "Israeli people of Hungarian-Jewish descent": "إسرائيليون من أصل مجري يهودي",
    "Israeli people of Indian-Jewish descent": "إسرائيليون من أصل هندي يهودي",
    "Israeli people of Iranian-Jewish descent": "إسرائيليون من أصل إيراني يهودي",
    "Israeli people of Iraqi-Jewish descent": "إسرائيليون من أصل عراقي يهودي",
    "Israeli people of Irish-Jewish descent": "إسرائيليون من أصل أيرلندي يهودي",
    "Israeli people of Italian-Jewish descent": "إسرائيليون من أصل إيطالي يهودي",
    "Israeli people of Jamaican-Jewish descent": "إسرائيليون من أصل جامايكي يهودي",
    "Israeli people of Kazakhstani-Jewish descent": "إسرائيليون من أصل كازاخستاني يهودي",
    "Israeli people of Kurdish-Jewish descent": "إسرائيليون من أصل كردي يهودي",
    "Israeli people of Latvian-Jewish descent": "إسرائيليون من أصل لاتفي يهودي",
    "Israeli people of Lebanese-Jewish descent": "إسرائيليون من أصل لبناني يهودي",
    "Israeli people of Libyan-Jewish descent": "إسرائيليون من أصل ليبي يهودي",
    "Israeli people of Lithuanian-Jewish descent": "إسرائيليون من أصل ليتواني يهودي",
    "Israeli people of Macedonian-Jewish descent": "إسرائيليون من أصل مقدوني يهودي",
    "Israeli people of Mexican-Jewish descent": "إسرائيليون من أصل مكسيكي يهودي",
    "Israeli people of Moldovan-Jewish descent": "إسرائيليون من أصل مولدوفي يهودي",
    "Israeli people of Moroccan-Jewish descent": "إسرائيليون من أصل مغربي يهودي",
    "Israeli people of North African-Jewish descent": "إسرائيليون من أصل إفريقي شمالي يهودي",
    "Israeli people of North American-Jewish descent": "إسرائيليون من أصل أمريكي شمالي يهودي",
    "Israeli people of Polish-Jewish descent": "إسرائيليون من أصل بولندي يهودي",
    "Israeli people of Portuguese-Jewish descent": "إسرائيليون من أصل برتغالي يهودي",
    "Israeli people of Romanian-Jewish descent": "إسرائيليون من أصل روماني يهودي",
    "Israeli people of Russian-Jewish descent": "إسرائيليون من أصل روسي يهودي",
    "Israeli people of Serbian-Jewish descent": "إسرائيليون من أصل صربي يهودي",
    "Israeli people of Slovak-Jewish descent": "إسرائيليون من أصل سلوفاكي يهودي",
    "Israeli people of South American-Jewish descent": "إسرائيليون من أصل أمريكي جنوبي يهودي",
    "Israeli people of Spanish-Jewish descent": "إسرائيليون من أصل إسباني يهودي",
    "Israeli people of Surinamese-Jewish descent": "إسرائيليون من أصل سورينامي يهودي",
    "Israeli people of Swedish-Jewish descent": "إسرائيليون من أصل سويدي يهودي",
    "Israeli people of Swiss-Jewish descent": "إسرائيليون من أصل سويسري يهودي",
    "Israeli people of Syrian-Jewish descent": "إسرائيليون من أصل سوري يهودي",
    "Israeli people of Tunisian-Jewish descent": "إسرائيليون من أصل تونسي يهودي",
    "Israeli people of Turkish-Jewish descent": "إسرائيليون من أصل تركي يهودي",
    "Israeli people of Ukrainian-Jewish descent": "إسرائيليون من أصل أوكراني يهودي",
    "Israeli people of Uruguayan-Jewish descent": "إسرائيليون من أصل أوروغوياني يهودي",
    "Israeli people of Uzbekistani-Jewish descent": "إسرائيليون من أصل أوزبكستاني يهودي",
    "Israeli people of Venezuelan-Jewish descent": "إسرائيليون من أصل فنزويلي يهودي",
    "Israeli people of Yemeni-Jewish descent": "إسرائيليون من أصل يمني يهودي",
    "Italian people of Asian-Jewish descent": "إيطاليون من أصل آسيوي يهودي",
    "Italian people of Dutch-Jewish descent": "إيطاليون من أصل هولندي يهودي",
    "Italian people of European-Jewish descent": "إيطاليون من أصل أوروبي يهودي",
    "Italian people of French-Jewish descent": "إيطاليون من أصل فرنسي يهودي",
    "Italian people of Lebanese-Jewish descent": "إيطاليون من أصل لبناني يهودي",
    "Italian people of Libyan-Jewish descent": "إيطاليون من أصل ليبي يهودي",
    "Italian people of Lithuanian-Jewish descent": "إيطاليون من أصل ليتواني يهودي",
    "Italian people of Polish-Jewish descent": "إيطاليون من أصل بولندي يهودي",
    "Italian people of Russian-Jewish descent": "إيطاليون من أصل روسي يهودي",
    "Italian people of Swiss-Jewish descent": "إيطاليون من أصل سويسري يهودي",
    "Italian people of Syrian-Jewish descent": "إيطاليون من أصل سوري يهودي",
    "Italian people of Tunisian-Jewish descent": "إيطاليون من أصل تونسي يهودي",
    "Italian people of Ukrainian-Jewish descent": "إيطاليون من أصل أوكراني يهودي",
    "Italian-Jewish culture in Israel": "ثقافة إيطالية يهودية في إسرائيل",
    "Italian-Jewish culture in Tunisia": "ثقافة إيطالية يهودية في تونس",
    "Italian-Jewish diaspora": "شتات إيطالي يهودي",
    "Japanese people of American-Jewish descent": "يابانيون من أصل أمريكي يهودي",
    "Japanese people of Polish-Jewish descent": "يابانيون من أصل بولندي يهودي",
    "Japanese people of Russian-Jewish descent": "يابانيون من أصل روسي يهودي",
    "Jews and Judaism in Dutch Caribbean": "اليهود واليهودية في كاريبيون هولنديون",
    "Jews from Dutch Caribbean": "يهود من كاريبيون هولنديون",
    "Kurdish-Jewish culture in Israel": "ثقافة كردية يهودية في إسرائيل",
    "Kurdish-Jewish diaspora": "شتات كردي يهودي",
    "Latvian people of Russian-Jewish descent": "لاتفيون من أصل روسي يهودي",
    "Latvian-Jewish culture in Israel": "ثقافة لاتفية يهودية في إسرائيل",
    "Latvian-Jewish culture in United States": "ثقافة لاتفية يهودية في الولايات المتحدة",
    "Latvian-Jewish diaspora": "شتات لاتفي يهودي",
    "Lebanese people of Syrian-Jewish descent": "لبنانيون من أصل سوري يهودي",
    "Lebanese-Jewish diaspora in United States": "شتات لبناني يهودي في الولايات المتحدة",
    "Lebanese-Jewish diaspora": "شتات لبناني يهودي",
    "Libyan-Jewish culture in Israel": "ثقافة ليبية يهودية في إسرائيل",
    "Libyan-Jewish diaspora": "شتات ليبي يهودي",
    "Lithuanian-Jewish culture in Israel": "ثقافة ليتوانية يهودية في إسرائيل",
    "Lithuanian-Jewish culture in Jerusalem": "ثقافة ليتوانية يهودية في القدس",
    "Lithuanian-Jewish culture in Maryland": "ثقافة ليتوانية يهودية في ماريلند",
    "Lithuanian-Jewish culture in New York (state)": "ثقافة ليتوانية يهودية في ولاية نيويورك",
    "Lithuanian-Jewish culture in United States by state": "ثقافة ليتوانية يهودية في الولايات المتحدة حسب الولاية",
    "Lithuanian-Jewish culture in United States": "ثقافة ليتوانية يهودية في الولايات المتحدة",
    "Lithuanian-Jewish diaspora": "شتات ليتواني يهودي",
    "Mexican people of Austrian-Jewish descent": "مكسيكيون من أصل نمساوي يهودي",
    "Mexican people of Belarusian-Jewish descent": "مكسيكيون من أصل بيلاروسي يهودي",
    "Mexican people of British-Jewish descent": "مكسيكيون من أصل بريطاني يهودي",
    "Mexican people of Bulgarian-Jewish descent": "مكسيكيون من أصل بلغاري يهودي",
    "Mexican people of Costa Rican-Jewish descent": "مكسيكيون من أصل كوستاريكي يهودي",
    "Mexican people of English-Jewish descent": "مكسيكيون من أصل إنجليزي يهودي",
    "Mexican people of European-Jewish descent": "مكسيكيون من أصل أوروبي يهودي",
    "Mexican people of German-Jewish descent": "مكسيكيون من أصل ألماني يهودي",
    "Mexican people of Hungarian-Jewish descent": "مكسيكيون من أصل مجري يهودي",
    "Mexican people of Latvian-Jewish descent": "مكسيكيون من أصل لاتفي يهودي",
    "Mexican people of Lebanese-Jewish descent": "مكسيكيون من أصل لبناني يهودي",
    "Mexican people of Lithuanian-Jewish descent": "مكسيكيون من أصل ليتواني يهودي",
    "Mexican people of Polish-Jewish descent": "مكسيكيون من أصل بولندي يهودي",
    "Mexican people of Portuguese-Jewish descent": "مكسيكيون من أصل برتغالي يهودي",
    "Mexican people of Romanian-Jewish descent": "مكسيكيون من أصل روماني يهودي",
    "Mexican people of Russian-Jewish descent": "مكسيكيون من أصل روسي يهودي",
    "Mexican people of Slovak-Jewish descent": "مكسيكيون من أصل سلوفاكي يهودي",
    "Mexican people of Spanish-Jewish descent": "مكسيكيون من أصل إسباني يهودي",
    "Mexican people of Syrian-Jewish descent": "مكسيكيون من أصل سوري يهودي",
    "Mexican people of Turkish-Jewish descent": "مكسيكيون من أصل تركي يهودي",
    "Mexican people of Ukrainian-Jewish descent": "مكسيكيون من أصل أوكراني يهودي",
    "Moldovan-Jewish diaspora": "شتات مولدوفي يهودي",
    "Monegasque people of Lebanese-Jewish descent": "موناكيون من أصل لبناني يهودي",
    "Monegasque people of Syrian-Jewish descent": "موناكيون من أصل سوري يهودي",
    "Monegasque people of Uruguayan-Jewish descent": "موناكيون من أصل أوروغوياني يهودي",
    "Montenegrin people of American-Jewish descent": "مونتينيغريون من أصل أمريكي يهودي",
    "Montenegrin people of German-Jewish descent": "مونتينيغريون من أصل ألماني يهودي",
    "Moroccan people of Italian-Jewish descent": "مغاربة من أصل إيطالي يهودي",
    "Moroccan people of Spanish-Jewish descent": "مغاربة من أصل إسباني يهودي",
    "Moroccan-Jewish culture in Israel": "ثقافة مغربية يهودية في إسرائيل",
    "Moroccan-Jewish diaspora": "شتات مغربي يهودي",
    "Nicaraguan people of Polish-Jewish descent": "نيكاراغويون من أصل بولندي يهودي",
    "North African-Jewish culture in Israel": "ثقافة إفريقية شمالية يهودية في إسرائيل",
    "North African-Jewish culture in United States": "ثقافة إفريقية شمالية يهودية في الولايات المتحدة",
    "North African-Jewish diaspora": "شتات إفريقي شمالي يهودي",
    "North American people of Asian-Jewish descent": "أمريكيون شماليون من أصل آسيوي يهودي",
    "North American people of European-Jewish descent": "أمريكيون شماليون من أصل أوروبي يهودي",
    "North American-Jewish culture in Israel": "ثقافة أمريكية شمالية يهودية في إسرائيل",
    "North American-Jewish diaspora": "شتات أمريكي شمالي يهودي",
    "Norwegian people of Austrian-Jewish descent": "نرويجيون من أصل نمساوي يهودي",
    "Norwegian people of Danish-Jewish descent": "نرويجيون من أصل دنماركي يهودي",
    "Norwegian people of German-Jewish descent": "نرويجيون من أصل ألماني يهودي",
    "Norwegian people of Lithuanian-Jewish descent": "نرويجيون من أصل ليتواني يهودي",
    "Norwegian people of Moroccan-Jewish descent": "نرويجيون من أصل مغربي يهودي",
    "Norwegian people of Russian-Jewish descent": "نرويجيون من أصل روسي يهودي",
    "Oceanian people of African-Jewish descent": "أوقيانوسيون من أصل إفريقي يهودي",
    "Oceanian people of Asian-Jewish descent": "أوقيانوسيون من أصل آسيوي يهودي",
    "Oceanian people of European-Jewish descent": "أوقيانوسيون من أصل أوروبي يهودي",
    "Pakistani people of American-Jewish descent": "باكستانيون من أصل أمريكي يهودي",
    "Pakistani people of Austrian-Jewish descent": "باكستانيون من أصل نمساوي يهودي",
    "Pakistani people of German-Jewish descent": "باكستانيون من أصل ألماني يهودي",
    "Pakistani people of Polish-Jewish descent": "باكستانيون من أصل بولندي يهودي",
    "Pakistani people of Russian-Jewish descent": "باكستانيون من أصل روسي يهودي",
    "Panamanian people of German-Jewish descent": "بنميون من أصل ألماني يهودي",
    "Panamanian people of Moroccan-Jewish descent": "بنميون من أصل مغربي يهودي",
    "Paraguayan people of German-Jewish descent": "بارغوايانيون من أصل ألماني يهودي",
    "Paraguayan people of Russian-Jewish descent": "بارغوايانيون من أصل روسي يهودي",
    "Paraguayan people of Ukrainian-Jewish descent": "بارغوايانيون من أصل أوكراني يهودي",
    "People from Northern Ireland of Russian-Jewish descent": "أشخاص من أيرلندا الشمالية من أصل روسي يهودي",
    "People of Afghan-Jewish descent": "أشخاص من أصل أفغاني يهودي",
    "People of African-Jewish descent": "أشخاص من أصل إفريقي يهودي",
    "People of Algerian-Jewish descent": "أشخاص من أصل جزائري يهودي",
    "People of American-Jewish descent": "أشخاص من أصل أمريكي يهودي",
    "People of Argentine-Jewish descent": "أشخاص من أصل أرجنتيني يهودي",
    "People of Asian-Jewish descent": "أشخاص من أصل آسيوي يهودي",
    "People of Australian-Jewish descent": "أشخاص من أصل أسترالي يهودي",
    "People of Austrian-Jewish descent": "أشخاص من أصل نمساوي يهودي",
    "People of Azerbaijani-Jewish descent": "أشخاص من أصل أذربيجاني يهودي",
    "People of Belarusian-Jewish descent": "أشخاص من أصل بيلاروسي يهودي",
    "People of Belgian-Jewish descent": "أشخاص من أصل بلجيكي يهودي",
    "People of Bosnia and Herzegovina-Jewish descent": "أشخاص من أصل بوسني يهودي",
    "People of Brazilian-Jewish descent": "أشخاص من أصل برازيلي يهودي",
    "People of British-Jewish descent": "أشخاص من أصل بريطاني يهودي",
    "People of Bulgarian-Jewish descent": "أشخاص من أصل بلغاري يهودي",
    "People of Burmese-Jewish descent": "أشخاص من أصل بورمي يهودي",
    "People of Canadian-Jewish descent": "أشخاص من أصل كندي يهودي",
    "People of Chilean-Jewish descent": "أشخاص من أصل تشيلي يهودي",
    "People of Chinese-Jewish descent": "أشخاص من أصل صيني يهودي",
    "People of Colombian-Jewish descent": "أشخاص من أصل كولومبي يهودي",
    "People of Costa Rican-Jewish descent": "أشخاص من أصل كوستاريكي يهودي",
    "People of Croatian-Jewish descent": "أشخاص من أصل كرواتي يهودي",
    "People of Cuban-Jewish descent": "أشخاص من أصل كوبي يهودي",
    "People of Czech-Jewish descent": "أشخاص من أصل تشيكي يهودي",
    "People of Danish-Jewish descent": "أشخاص من أصل دنماركي يهودي",
    "People of Dutch-Jewish descent": "أشخاص من أصل هولندي يهودي",
    "People of Egyptian-Jewish descent": "أشخاص من أصل مصري يهودي",
    "People of English-Jewish descent": "أشخاص من أصل إنجليزي يهودي",
    "People of Estonian-Jewish descent": "أشخاص من أصل إستوني يهودي",
    "People of Ethiopian-Jewish descent": "أشخاص من أصل إثيوبي يهودي",
    "People of European-Jewish descent": "أشخاص من أصل أوروبي يهودي",
    "People of Finnish-Jewish descent": "أشخاص من أصل فنلندي يهودي",
    "People of French-Jewish descent": "أشخاص من أصل فرنسي يهودي",
    "People of Georgian-Jewish descent": "أشخاص من أصل جورجي يهودي",
    "People of German-Jewish descent": "أشخاص من أصل ألماني يهودي",
    "People of Hungarian-Jewish descent": "أشخاص من أصل مجري يهودي",
    "People of Indian-Jewish descent": "أشخاص من أصل هندي يهودي",
    "People of Iranian-Jewish descent": "أشخاص من أصل إيراني يهودي",
    "People of Iraqi-Jewish descent": "أشخاص من أصل عراقي يهودي",
    "People of Irish-Jewish descent": "أشخاص من أصل أيرلندي يهودي",
    "People of Italian-Jewish descent": "أشخاص من أصل إيطالي يهودي",
    "People of Jamaican-Jewish descent": "أشخاص من أصل جامايكي يهودي",
    "People of Kazakhstani-Jewish descent": "أشخاص من أصل كازاخستاني يهودي",
    "People of Kurdish-Jewish descent": "أشخاص من أصل كردي يهودي",
    "People of Latvian-Jewish descent": "أشخاص من أصل لاتفي يهودي",
    "People of Lebanese-Jewish descent": "أشخاص من أصل لبناني يهودي",
    "People of Libyan-Jewish descent": "أشخاص من أصل ليبي يهودي",
    "People of Lithuanian-Jewish descent": "أشخاص من أصل ليتواني يهودي",
    "People of Mexican-Jewish descent": "أشخاص من أصل مكسيكي يهودي",
    "People of Moldovan-Jewish descent": "أشخاص من أصل مولدوفي يهودي",
    "People of Moroccan-Jewish descent": "أشخاص من أصل مغربي يهودي",
    "People of North African-Jewish descent": "أشخاص من أصل إفريقي شمالي يهودي",
    "People of North American-Jewish descent": "أشخاص من أصل أمريكي شمالي يهودي",
    "People of Palestinian-Jewish descent": "أشخاص من أصل فلسطيني يهودي",
    "People of Polish-Jewish descent": "أشخاص من أصل بولندي يهودي",
    "People of Portuguese-Jewish descent": "أشخاص من أصل برتغالي يهودي",
    "People of Romanian-Jewish descent": "أشخاص من أصل روماني يهودي",
    "People of Russian-Jewish descent": "أشخاص من أصل روسي يهودي",
    "People of Scottish-Jewish descent": "أشخاص من أصل إسكتلندي يهودي",
    "People of Serbian-Jewish descent": "أشخاص من أصل صربي يهودي",
    "People of Slovak-Jewish descent": "أشخاص من أصل سلوفاكي يهودي",
    "People of South American-Jewish descent": "أشخاص من أصل أمريكي جنوبي يهودي",
    "People of Spanish-Jewish descent": "أشخاص من أصل إسباني يهودي",
    "People of Surinamese-Jewish descent": "أشخاص من أصل سورينامي يهودي",
    "People of Swedish-Jewish descent": "أشخاص من أصل سويدي يهودي",
    "People of Swiss-Jewish descent": "أشخاص من أصل سويسري يهودي",
    "People of Syrian-Jewish descent": "أشخاص من أصل سوري يهودي",
    "People of Tajikistani-Jewish descent": "أشخاص من أصل طاجيكي يهودي",
    "People of Tunisian-Jewish descent": "أشخاص من أصل تونسي يهودي",
    "People of Turkish-Jewish descent": "أشخاص من أصل تركي يهودي",
    "People of Ukrainian-Jewish descent": "أشخاص من أصل أوكراني يهودي",
    "People of Uruguayan-Jewish descent": "أشخاص من أصل أوروغوياني يهودي",
    "People of Venezuelan-Jewish descent": "أشخاص من أصل فنزويلي يهودي",
    "People of Welsh-Jewish descent": "أشخاص من أصل ويلزي يهودي",
    "People of Yemeni-Jewish descent": "أشخاص من أصل يمني يهودي",
    "Peruvian people of German-Jewish descent": "بيرويون من أصل ألماني يهودي",
    "Peruvian people of Hungarian-Jewish descent": "بيرويون من أصل مجري يهودي",
    "Peruvian people of Moroccan-Jewish descent": "بيرويون من أصل مغربي يهودي",
    "Peruvian people of Polish-Jewish descent": "بيرويون من أصل بولندي يهودي",
    "Peruvian people of Romanian-Jewish descent": "بيرويون من أصل روماني يهودي",
    "Polish people of Austrian-Jewish descent": "بولنديون من أصل نمساوي يهودي",
    "Polish people of Latvian-Jewish descent": "بولنديون من أصل لاتفي يهودي",
    "Polish people of Lithuanian-Jewish descent": "بولنديون من أصل ليتواني يهودي",
    "Polish people of Portuguese-Jewish descent": "بولنديون من أصل برتغالي يهودي",
    "Polish people of Russian-Jewish descent": "بولنديون من أصل روسي يهودي",
    "Polish people of Tunisian-Jewish descent": "بولنديون من أصل تونسي يهودي",
    "Polish people of Ukrainian-Jewish descent": "بولنديون من أصل أوكراني يهودي",
    "Polish-Jewish culture in Baltimore": "ثقافة بولندية يهودية في بالتيمور",
    "Polish-Jewish culture in Canada": "ثقافة بولندية يهودية في كندا",
    "Polish-Jewish culture in Israel": "ثقافة بولندية يهودية في إسرائيل",
    "Polish-Jewish culture in Maryland": "ثقافة بولندية يهودية في ماريلند",
    "Polish-Jewish culture in New York (state)": "ثقافة بولندية يهودية في ولاية نيويورك",
    "Polish-Jewish culture in New York City": "ثقافة بولندية يهودية في مدينة نيويورك",
    "Polish-Jewish culture in United Kingdom": "ثقافة بولندية يهودية في المملكة المتحدة",
    "Polish-Jewish culture in United States by city": "ثقافة بولندية يهودية في الولايات المتحدة حسب المدينة",
    "Polish-Jewish culture in United States by state": "ثقافة بولندية يهودية في الولايات المتحدة حسب الولاية",
    "Polish-Jewish culture in United States": "ثقافة بولندية يهودية في الولايات المتحدة",
    "Polish-Jewish diaspora": "شتات بولندي يهودي",
    "Portuguese people of Moroccan-Jewish descent": "برتغاليون من أصل مغربي يهودي",
    "Portuguese-Jewish culture in United States": "ثقافة برتغالية يهودية في الولايات المتحدة",
    "Portuguese-Jewish diaspora in Africa": "شتات برتغالي يهودي في إفريقيا",
    "Portuguese-Jewish diaspora in Europe": "شتات برتغالي يهودي في أوروبا",
    "Portuguese-Jewish diaspora": "شتات برتغالي يهودي",
    "Rhodesian people of Lithuanian-Jewish descent": "رودوسيون من أصل ليتواني يهودي",
    "Romanian people of Austrian-Jewish descent": "رومان من أصل نمساوي يهودي",
    "Romanian people of Czech-Jewish descent": "رومان من أصل تشيكي يهودي",
    "Romanian people of Hungarian-Jewish descent": "رومان من أصل مجري يهودي",
    "Romanian people of Polish-Jewish descent": "رومان من أصل بولندي يهودي",
    "Romanian people of Turkish-Jewish descent": "رومان من أصل تركي يهودي",
    "Romanian people of Ukrainian-Jewish descent": "رومان من أصل أوكراني يهودي",
    "Romanian-Jewish culture in Canada": "ثقافة رومانية يهودية في كندا",
    "Romanian-Jewish culture in Israel": "ثقافة رومانية يهودية في إسرائيل",
    "Romanian-Jewish culture in New York (state)": "ثقافة رومانية يهودية في ولاية نيويورك",
    "Romanian-Jewish culture in United States": "ثقافة رومانية يهودية في الولايات المتحدة",
    "Romanian-Jewish diaspora": "شتات روماني يهودي",
    "Russian people of Austrian-Jewish descent": "روس من أصل نمساوي يهودي",
    "Russian people of Belarusian-Jewish descent": "روس من أصل بيلاروسي يهودي",
    "Russian people of German-Jewish descent": "روس من أصل ألماني يهودي",
    "Russian people of Lithuanian-Jewish descent": "روس من أصل ليتواني يهودي",
    "Russian people of Moldovan-Jewish descent": "روس من أصل مولدوفي يهودي",
    "Russian people of Polish-Jewish descent": "روس من أصل بولندي يهودي",
    "Russian people of Ukrainian-Jewish descent": "روس من أصل أوكراني يهودي",
    "Russian-Jewish culture in Baltimore": "ثقافة روسية يهودية في بالتيمور",
    "Russian-Jewish culture in Canada": "ثقافة روسية يهودية في كندا",
    "Russian-Jewish culture in Israel": "ثقافة روسية يهودية في إسرائيل",
    "Russian-Jewish culture in Maryland": "ثقافة روسية يهودية في ماريلند",
    "Russian-Jewish culture in New York (state)": "ثقافة روسية يهودية في ولاية نيويورك",
    "Russian-Jewish culture in New York City": "ثقافة روسية يهودية في مدينة نيويورك",
    "Russian-Jewish culture in United States by city": "ثقافة روسية يهودية في الولايات المتحدة حسب المدينة",
    "Russian-Jewish culture in United States by state": "ثقافة روسية يهودية في الولايات المتحدة حسب الولاية",
    "Russian-Jewish culture in United States": "ثقافة روسية يهودية في الولايات المتحدة",
    "Russian-Jewish diaspora in Asia": "شتات روسي يهودي في آسيا",
    "Russian-Jewish diaspora in Europe": "شتات روسي يهودي في أوروبا",
    "Russian-Jewish diaspora in North America": "شتات روسي يهودي في أمريكا الشمالية",
    "Russian-Jewish diaspora": "شتات روسي يهودي",
    "Russian-Jewish surnames": "ألقاب روسية يهودية",
    "Salvadoran people of German-Jewish descent": "سلفادوريون من أصل ألماني يهودي",
    "Saudi Arabian people of Ukrainian-Jewish descent": "سعوديون من أصل أوكراني يهودي",
    "Scottish people of German-Jewish descent": "إسكتلنديون من أصل ألماني يهودي",
    "Scottish people of Lithuanian-Jewish descent": "إسكتلنديون من أصل ليتواني يهودي",
    "Scottish people of Polish-Jewish descent": "إسكتلنديون من أصل بولندي يهودي",
    "Scottish people of Russian-Jewish descent": "إسكتلنديون من أصل روسي يهودي",
    "Serbian people of Croatian-Jewish descent": "صرب من أصل كرواتي يهودي",
    "Serbian people of Polish-Jewish descent": "صرب من أصل بولندي يهودي",
    "Singaporean people of Iraqi-Jewish descent": "سنغافوريون من أصل عراقي يهودي",
    "Slovak-Jewish culture in Israel": "ثقافة سلوفاكية يهودية في إسرائيل",
    "Slovak-Jewish culture in United States": "ثقافة سلوفاكية يهودية في الولايات المتحدة",
    "Slovak-Jewish diaspora": "شتات سلوفاكي يهودي",
    "Slovenian people of Ukrainian-Jewish descent": "سلوفينيون من أصل أوكراني يهودي",
    "South American people of Asian-Jewish descent": "أمريكيون جنوبيون من أصل آسيوي يهودي",
    "South American people of European-Jewish descent": "أمريكيون جنوبيون من أصل أوروبي يهودي",
    "South American-Jewish culture in Israel": "ثقافة أمريكية جنوبية يهودية في إسرائيل",
    "South American-Jewish diaspora": "شتات أمريكي جنوبي يهودي",
    "South Korean people of Russian-Jewish descent": "كوريون جنوبيون من أصل روسي يهودي",
    "Soviet people of German-Jewish descent": "سوفيت من أصل ألماني يهودي",
    "Soviet people of Moldovan-Jewish descent": "سوفيت من أصل مولدوفي يهودي",
    "Soviet people of Polish-Jewish descent": "سوفيت من أصل بولندي يهودي",
    "Spanish people of French-Jewish descent": "إسبان من أصل فرنسي يهودي",
    "Spanish people of German-Jewish descent": "إسبان من أصل ألماني يهودي",
    "Spanish people of Lebanese-Jewish descent": "إسبان من أصل لبناني يهودي",
    "Spanish people of Moroccan-Jewish descent": "إسبان من أصل مغربي يهودي",
    "Spanish people of Russian-Jewish descent": "إسبان من أصل روسي يهودي",
    "Spanish-Jewish culture in United States": "ثقافة إسبانية يهودية في الولايات المتحدة",
    "Spanish-Jewish diaspora in Europe": "شتات إسباني يهودي في أوروبا",
    "Spanish-Jewish diaspora": "شتات إسباني يهودي",
    "Swedish people of Austrian-Jewish descent": "سويديون من أصل نمساوي يهودي",
    "Swedish people of Czech-Jewish descent": "سويديون من أصل تشيكي يهودي",
    "Swedish people of Dutch-Jewish descent": "سويديون من أصل هولندي يهودي",
    "Swedish people of Finnish-Jewish descent": "سويديون من أصل فنلندي يهودي",
    "Swedish people of German-Jewish descent": "سويديون من أصل ألماني يهودي",
    "Swedish people of Polish-Jewish descent": "سويديون من أصل بولندي يهودي",
    "Swedish people of Russian-Jewish descent": "سويديون من أصل روسي يهودي",
    "Swiss people of Belarusian-Jewish descent": "سويسريون من أصل بيلاروسي يهودي",
    "Swiss people of Egyptian-Jewish descent": "سويسريون من أصل مصري يهودي",
    "Swiss people of German-Jewish descent": "سويسريون من أصل ألماني يهودي",
    "Swiss people of Lithuanian-Jewish descent": "سويسريون من أصل ليتواني يهودي",
    "Swiss people of Polish-Jewish descent": "سويسريون من أصل بولندي يهودي",
    "Swiss people of Russian-Jewish descent": "سويسريون من أصل روسي يهودي",
    "Swiss people of Turkish-Jewish descent": "سويسريون من أصل تركي يهودي",
    "Swiss people of Ukrainian-Jewish descent": "سويسريون من أصل أوكراني يهودي",
    "Syrian-Jewish culture in New York (state)": "ثقافة سورية يهودية في ولاية نيويورك",
    "Syrian-Jewish diaspora in United States": "شتات سوري يهودي في الولايات المتحدة",
    "Syrian-Jewish diaspora": "شتات سوري يهودي",
    "Trinidad and Tobago people of English-Jewish descent": "ترنيداديون من أصل إنجليزي يهودي",
    "Tunisian people of Italian-Jewish descent": "تونسيون من أصل إيطالي يهودي",
    "Tunisian people of Polish-Jewish descent": "تونسيون من أصل بولندي يهودي",
    "Tunisian-Jewish culture in Israel": "ثقافة تونسية يهودية في إسرائيل",
    "Tunisian-Jewish diaspora in France": "شتات تونسي يهودي في فرنسا",
    "Tunisian-Jewish diaspora": "شتات تونسي يهودي",
    "Turkish people of Polish-Jewish descent": "أتراك من أصل بولندي يهودي",
    "Turkish people of Portuguese-Jewish descent": "أتراك من أصل برتغالي يهودي",
    "Turkish-Jewish culture in Israel": "ثقافة تركية يهودية في إسرائيل",
    "Turkish-Jewish culture in United States": "ثقافة تركية يهودية في الولايات المتحدة",
    "Turkish-Jewish diaspora": "شتات تركي يهودي",
    "Ukrainian people of Lithuanian-Jewish descent": "أوكرانيون من أصل ليتواني يهودي",
    "Ukrainian people of Romanian-Jewish descent": "أوكرانيون من أصل روماني يهودي",
    "Ukrainian-Jewish culture in Baltimore": "ثقافة أوكرانية يهودية في بالتيمور",
    "Ukrainian-Jewish culture in Israel": "ثقافة أوكرانية يهودية في إسرائيل",
    "Ukrainian-Jewish culture in Maryland": "ثقافة أوكرانية يهودية في ماريلند",
    "Ukrainian-Jewish culture in New York (state)": "ثقافة أوكرانية يهودية في ولاية نيويورك",
    "Ukrainian-Jewish culture in New York City": "ثقافة أوكرانية يهودية في مدينة نيويورك",
    "Ukrainian-Jewish culture in United States by city": "ثقافة أوكرانية يهودية في الولايات المتحدة حسب المدينة",
    "Ukrainian-Jewish culture in United States by state": "ثقافة أوكرانية يهودية في الولايات المتحدة حسب الولاية",
    "Ukrainian-Jewish culture in United States": "ثقافة أوكرانية يهودية في الولايات المتحدة",
    "Ukrainian-Jewish diaspora": "شتات أوكراني يهودي",
    "Uruguayan people of Austrian-Jewish descent": "أوروغويانيون من أصل نمساوي يهودي",
    "Uruguayan people of German-Jewish descent": "أوروغويانيون من أصل ألماني يهودي",
    "Uruguayan people of Hungarian-Jewish descent": "أوروغويانيون من أصل مجري يهودي",
    "Uruguayan people of Latvian-Jewish descent": "أوروغويانيون من أصل لاتفي يهودي",
    "Uruguayan people of Lithuanian-Jewish descent": "أوروغويانيون من أصل ليتواني يهودي",
    "Uruguayan people of Polish-Jewish descent": "أوروغويانيون من أصل بولندي يهودي",
    "Uruguayan people of Romanian-Jewish descent": "أوروغويانيون من أصل روماني يهودي",
    "Uruguayan people of Russian-Jewish descent": "أوروغويانيون من أصل روسي يهودي",
    "Uruguayan people of Syrian-Jewish descent": "أوروغويانيون من أصل سوري يهودي",
    "Uruguayan people of Turkish-Jewish descent": "أوروغويانيون من أصل تركي يهودي",
    "Venezuelan people of Croatian-Jewish descent": "فنزويليون من أصل كرواتي يهودي",
    "Venezuelan people of European-Jewish descent": "فنزويليون من أصل أوروبي يهودي",
    "Venezuelan people of German-Jewish descent": "فنزويليون من أصل ألماني يهودي",
    "Venezuelan people of Hungarian-Jewish descent": "فنزويليون من أصل مجري يهودي",
    "Venezuelan people of Lebanese-Jewish descent": "فنزويليون من أصل لبناني يهودي",
    "Venezuelan people of Moroccan-Jewish descent": "فنزويليون من أصل مغربي يهودي",
    "Venezuelan people of Polish-Jewish descent": "فنزويليون من أصل بولندي يهودي",
    "Venezuelan people of Romanian-Jewish descent": "فنزويليون من أصل روماني يهودي",
    "Venezuelan people of Russian-Jewish descent": "فنزويليون من أصل روسي يهودي",
    "Venezuelan people of Ukrainian-Jewish descent": "فنزويليون من أصل أوكراني يهودي",
    "Welsh people of German-Jewish descent": "ويلزيون من أصل ألماني يهودي",
    "Welsh people of Moroccan-Jewish descent": "ويلزيون من أصل مغربي يهودي",
    "Yemeni-Jewish culture in Israel": "ثقافة يمنية يهودية في إسرائيل",
    "Yemeni-Jewish diaspora": "شتات يمني يهودي",
    "Zimbabwean people of Lithuanian-Jewish descent": "زيمبابويون من أصل ليتواني يهودي",
    "Zimbabwean people of Polish-Jewish descent": "زيمبابويون من أصل بولندي يهودي",
}


@pytest.mark.parametrize("category, expected_key", data_0.items(), ids=data_0.keys())
@pytest.mark.fast
def test_data_0(category: str, expected_key: str) -> None:
    label2 = resolve_label_ar(category)
    assert label2 == expected_key


@pytest.mark.parametrize("category, expected_key", male_tests.items(), ids=male_tests.keys())
@pytest.mark.fast
def test_male_tests(category: str, expected_key: str) -> None:
    label2 = resolve_label_ar(category)
    assert label2 == expected_key


to_test = [
    ("data_0", data_0, resolve_label_ar),
    ("male_tests", male_tests, resolve_label_ar),
    ("data_2", data_2, resolve_label_ar),
]


@pytest.mark.parametrize("name,data,callback", to_test)
@pytest.mark.dump
def test_non_dump(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)

    dump_diff(diff_result, name)
    dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
